(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     96152,       2502]
NotebookOptionsPosition[     94765,       2450]
NotebookOutlinePosition[     95157,       2467]
CellTagsIndexPosition[     95114,       2464]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "0MI ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["H", "\[PlusMinus]"], TraditionalForm]], "None"],
 " Loop"
}], "Title",
 CellChangeTimes->{{3.494173993503446*^9, 3.494174063630849*^9}, {
  3.494273926116295*^9, 3.4942739262590933`*^9}, {3.494273985760048*^9, 
  3.4942739863948927`*^9}}],

Cell["\<\
Zero-mass insertion charged Higgs loop
Flip Tanedo, 22 September 2010
See notes (15 Sept 2010) for a complete expression, this is just the \
dimensionless integral
2 November 2010: reprinted with minimal model c values
17 November 2010: reprinted with Y*=2 values\
\>", "Text",
 CellChangeTimes->{{3.494174068217937*^9, 3.49417411004747*^9}, {
  3.494253869802822*^9, 3.4942538746426287`*^9}, {3.49427398821201*^9, 
  3.4942739903229933`*^9}, {3.4976636799894857`*^9, 3.497663680189444*^9}, {
  3.499135403997547*^9, 3.499135410890438*^9}}],

Cell["\<\
Remarks: it seems like I sometimes use different conventions for mu to e; \
sometimes its L to R, sometimes R to L. Curious.\
\>", "Text",
 CellChangeTimes->{{3.494254958072184*^9, 3.494254993079158*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 CellChangeTimes->{{3.494250120621427*^9, 3.494250122567276*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "the", " ", "warp", " ", "factor"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "16"}]]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "warp", " ", "factor", " ", "that", " ", "appears", " ", "in", " ", 
    "functions"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"wi", "=", "1"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Approximate", " ", "warp", " ", "factor", " ", "for", " ", "limits", " ", 
    "of", " ", "integration"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"wii", "=", ".1"}], " ", ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Limits", " ", "for", " ", "x", " ", "integration"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "25"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Max", " ", "of", " ", "y", " ", "integration"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MwRp", "=", ".1"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylo", "=", ".001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yhi", "=", ".4"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "internal", " ", "propagator", " ", "cL", " ", "and", " ", 
    "cR"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cL", "=", ".657"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cR", "=", 
    RowBox[{"-", ".575"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "shorthand", " ", "for", " ", "Bessel", " ", "functions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Will", " ", "make", " ", "it", " ", "easier", " ", "to", " ", "plug", " ",
     "in", " ", "IR", " ", "limit"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bI", "[", 
   RowBox[{"a_", ",", "x_"}], "]"}], ":=", 
  RowBox[{"BesselI", "[", 
   RowBox[{"a", ",", "x"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bK", "[", 
    RowBox[{"a_", ",", "x_"}], "]"}], ":=", 
   RowBox[{"BesselK", "[", 
    RowBox[{"a", ",", "x"}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "Auxilliary", " ", "S", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S", "[", 
   RowBox[{"x_", ",", "cx_", ",", "xp_", ",", "cxp_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cx", ",", "x"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cx", ",", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Spp", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Spm", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "-", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Smp", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "-", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Smm", "[", 
    RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"S", "[", 
    RowBox[{"x", ",", 
     RowBox[{"c", "-", 
      RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
     RowBox[{"c", "-", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "Auxilliary", " ", "T", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x_", ",", "cx_", ",", "xp_", ",", "cxp_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cx", ",", "x"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cx", ",", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tpm", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"T", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "-", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tmp", "[", 
    RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"T", "[", 
    RowBox[{"x", ",", 
     RowBox[{"c", "-", 
      RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
     RowBox[{"c", "+", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"F", "-", 
    RowBox[{"tilde", " ", "functions", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"pull", " ", "out", " ", "R"}], ",", " ", 
       RowBox[{"R", "'"}], ",", " ", 
       RowBox[{"and", " ", "i"}]}], ")"}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "xp"}], ")"}], 
     RowBox[{"5", "/", "2"}]], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Smm", "[", 
      RowBox[{"x", ",", "y", ",", "cL"}], "]"}], " ", 
     RowBox[{"Smm", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
    RowBox[{"Smm", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cL"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmlL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "xp"}], ")"}], 
     RowBox[{"5", "/", "2"}]], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Smm", "[", 
      RowBox[{"xp", ",", "y", ",", "cL"}], "]"}], " ", 
     RowBox[{"Smm", "[", 
      RowBox[{"x", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
    RowBox[{"Smm", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cL"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FpgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Tpm", "[", 
      RowBox[{"x", ",", "y", ",", "cL"}], "]"}], " ", 
     RowBox[{"Tpm", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
    RowBox[{"Smm", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{"FplL", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "xp"}], ")"}], 
       RowBox[{"5", "/", "2"}]]}], 
     SuperscriptBox["y", "5"]], 
    FractionBox[
     RowBox[{
      RowBox[{"Tpm", "[", 
       RowBox[{"xp", ",", "y", ",", "cL"}], "]"}], " ", 
      RowBox[{"Tpm", "[", 
       RowBox[{"x", ",", 
        RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
     RowBox[{"Smm", "[", 
      RowBox[{"y", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Tmp", "[", 
      RowBox[{"x", ",", "y", ",", "cR"}], "]"}], " ", 
     RowBox[{"Tmp", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
    RowBox[{"Spp", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cR"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmlR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Tmp", "[", 
      RowBox[{"xp", ",", "y", ",", "cR"}], "]"}], " ", 
     RowBox[{"Tmp", "[", 
      RowBox[{"x", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
    RowBox[{"Spp", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cR"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FpgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "xp"}], ")"}], 
     RowBox[{"5", "/", "2"}]], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Spp", "[", 
      RowBox[{"x", ",", "y", ",", "cR"}], "]"}], " ", 
     RowBox[{"Spp", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
    RowBox[{"Spp", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{"FplR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]], 
     SuperscriptBox["y", "5"]], 
    FractionBox[
     RowBox[{
      RowBox[{"Spp", "[", 
       RowBox[{"xp", ",", "y", ",", "cR"}], "]"}], " ", 
      RowBox[{"Spp", "[", 
       RowBox[{"x", ",", 
        RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
     RowBox[{"Spp", "[", 
      RowBox[{"y", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Now", " ", "define", " ", "piecewise", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"FmgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"FmlL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FpL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"FpgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"FplL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"FmgR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"FmlR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FpR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{"FpgR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "\[GreaterEqual]", "xp"}]},
      {
       RowBox[{"FplR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "<", "xp"}]}
     }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Derivatives", " ", "of", " ", "these", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmgL", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmlL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmlL", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFpgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FpgL", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dFplL", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "z"], " ", 
     RowBox[{"FplL", "[", 
      RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmgR", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmlR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmlR", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFpgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FpgR", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dFplR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "z"], " ", 
     RowBox[{"FplR", "[", 
      RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Now", " ", "define", " ", "piecewise", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"dFmgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"dFmlL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFpL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"dFpgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"dFplL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"dFmgR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"dFmlR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dFpR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{"dFpgR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "\[GreaterEqual]", "xp"}]},
      {
       RowBox[{"dFplR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "<", "xp"}]}
     }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"0", "MI", " ", "Hpm", " ", "Loop"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "Testing", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FmR", "[", 
       RowBox[{"y", ",", "y", ",", "y", ",", "cR"}], "]"}], 
      FractionBox[
       SuperscriptBox["y", "5"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "1", ",", "25"}], "}"}]}], "]"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"plotfull", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FmR", "[", 
      RowBox[{"y", ",", "y", ",", "y", ",", "cL"}], "]"}], 
     FractionBox[
      SuperscriptBox["y", "5"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.494188335344782*^9, 3.4941884685930967`*^9}, {
   3.494188536188343*^9, 3.4941885586000423`*^9}, {3.494188745472253*^9, 
   3.4941887666653433`*^9}, {3.494188838696198*^9, 3.494188863432885*^9}, {
   3.4941890466501293`*^9, 3.49418905063725*^9}, {3.494200708466032*^9, 
   3.494200719688018*^9}, {3.494200992994225*^9, 3.494201055683305*^9}, 
   3.494248648633157*^9, {3.4942487351790743`*^9, 3.4942487414849253`*^9}, {
   3.494248900985841*^9, 3.494248921466607*^9}, {3.494249109132792*^9, 
   3.494249150648122*^9}, {3.4942491894407043`*^9, 3.4942492166862164`*^9}, {
   3.4942492616096907`*^9, 3.494249286443131*^9}, {3.494274003995892*^9, 
   3.494274005384844*^9}, {3.497663733553782*^9, 3.497663735035499*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0VV8bB3BDUpLIkPSjyFRSiJTpyUzGkCQkmTLeczMkijJHmVKhZJbM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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.001, 0.4}, {-289.5396973925338, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.4942010447061872`*^9, 3.494201056046627*^9}, {
   3.494248736059417*^9, 3.49424874276257*^9}, 3.494248874599257*^9, {
   3.49424891079576*^9, 3.494248924495442*^9}, {3.4942491218014936`*^9, 
   3.494249150957184*^9}, {3.494249200255123*^9, 3.494249225438973*^9}, {
   3.4942492647519197`*^9, 3.494249290637784*^9}, 3.49427401918294*^9, 
   3.497663740592284*^9, 3.4991353552062073`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IR calculation", "Section",
 CellChangeTimes->{{3.494248701576787*^9, 3.494248703204433*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "the", " ", "warp", " ", "factor"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w", "=", 
     SuperscriptBox["10", 
      RowBox[{"-", "16"}]]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "warp", " ", "factor", " ", "that", " ", "appears", " ", "in", " ", 
     "functions"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wi", "=", "1"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Approximate", " ", "warp", " ", "factor", " ", "for", " ", "limits", " ",
      "of", " ", "integration"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wii", "=", ".1"}], " ", ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"Limits", " ", "for", " ", "x", " ", "integration"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ymax", "=", "25"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Max", " ", "of", " ", "y", " ", "integration"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MwRp", "=", ".1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Define", " ", "internal", " ", "propagator", " ", "cL", " ", "and", " ", 
     "cR"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cL", "=", ".55"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cR", "=", 
     RowBox[{"-", ".55"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Define", " ", "shorthand", " ", "for", " ", "Bessel", " ", "functions"}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Will", " ", "make", " ", "it", " ", "easier", " ", "to", " ", "plug", 
     " ", "in", " ", "IR", " ", "limit"}], " ", "*)"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"c_", ",", "x_"}], "]"}], ":=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"Gamma", "[", 
       RowBox[{"c", "+", "1"}], "]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["x", "2"], ")"}], "c"]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bK", "[", 
     RowBox[{"c_", ",", "x_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Log", "[", 
           RowBox[{"x", "/", "2"}], "]"}]}], "-", ".577216"}], 
        RowBox[{"c", "\[Equal]", "0"}]},
       {
        RowBox[{
         FractionBox[
          RowBox[{"Gamma", "[", "c", "]"}], "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["2", "x"], ")"}], "c"]}], 
        RowBox[{"c", "\[NotEqual]", "0"}]}
      }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "Auxilliary", " ", "S", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"x_", ",", "cx_", ",", "xp_", ",", "cxp_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"bI", "[", 
       RowBox[{"cx", ",", "x"}], "]"}], 
      RowBox[{"bK", "[", 
       RowBox[{"cxp", ",", "xp"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"bI", "[", 
       RowBox[{"cxp", ",", "xp"}], "]"}], 
      RowBox[{"bK", "[", 
       RowBox[{"cx", ",", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Spp", "[", 
     RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
    RowBox[{"S", "[", 
     RowBox[{"x", ",", 
      RowBox[{"c", "+", 
       RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
      RowBox[{"c", "+", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Spm", "[", 
     RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
    RowBox[{"S", "[", 
     RowBox[{"x", ",", 
      RowBox[{"c", "+", 
       RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
      RowBox[{"c", "-", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Smp", "[", 
     RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
    RowBox[{"S", "[", 
     RowBox[{"x", ",", 
      RowBox[{"c", "-", 
       RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
      RowBox[{"c", "+", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Smm", "[", 
     RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
    RowBox[{"S", "[", 
     RowBox[{"x", ",", 
      RowBox[{"c", "-", 
       RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
      RowBox[{"c", "-", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "Auxilliary", " ", "T", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"x_", ",", "cx_", ",", "xp_", ",", "cxp_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"bI", "[", 
       RowBox[{"cx", ",", "x"}], "]"}], 
      RowBox[{"bK", "[", 
       RowBox[{"cxp", ",", "xp"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"bI", "[", 
       RowBox[{"cxp", ",", "xp"}], "]"}], 
      RowBox[{"bK", "[", 
       RowBox[{"cx", ",", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tpm", "[", 
     RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
    RowBox[{"T", "[", 
     RowBox[{"x", ",", 
      RowBox[{"c", "+", 
       RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
      RowBox[{"c", "-", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tmp", "[", 
     RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
    RowBox[{"T", "[", 
     RowBox[{"x", ",", 
      RowBox[{"c", "-", 
       RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
      RowBox[{"c", "+", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"F", "-", 
     RowBox[{"tilde", " ", "functions", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pull", " ", "out", " ", "R"}], ",", " ", 
        RowBox[{"R", "'"}], ",", " ", 
        RowBox[{"and", " ", "i"}]}], ")"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FmgL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "xp"}], ")"}], 
       RowBox[{"5", "/", "2"}]], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Smm", "[", 
        RowBox[{"x", ",", "y", ",", "cL"}], "]"}], " ", 
       RowBox[{"Smm", "[", 
        RowBox[{"xp", ",", 
         RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
      RowBox[{"Smm", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FmlL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "xp"}], ")"}], 
       RowBox[{"5", "/", "2"}]], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Smm", "[", 
        RowBox[{"xp", ",", "y", ",", "cL"}], "]"}], " ", 
       RowBox[{"Smm", "[", 
        RowBox[{"x", ",", 
         RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
      RowBox[{"Smm", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FpgL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", " ", "xp"}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Tpm", "[", 
        RowBox[{"x", ",", "y", ",", "cL"}], "]"}], " ", 
       RowBox[{"Tpm", "[", 
        RowBox[{"xp", ",", 
         RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
      RowBox[{"Smm", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FplL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", " ", "xp"}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Tpm", "[", 
        RowBox[{"xp", ",", "y", ",", "cL"}], "]"}], " ", 
       RowBox[{"Tpm", "[", 
        RowBox[{"x", ",", 
         RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
      RowBox[{"Smm", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FmgR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", " ", "xp"}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Tmp", "[", 
        RowBox[{"x", ",", "y", ",", "cR"}], "]"}], " ", 
       RowBox[{"Tmp", "[", 
        RowBox[{"xp", ",", 
         RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
      RowBox[{"Spp", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FmlR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", " ", "xp"}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Tmp", "[", 
        RowBox[{"xp", ",", "y", ",", "cR"}], "]"}], " ", 
       RowBox[{"Tmp", "[", 
        RowBox[{"x", ",", 
         RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
      RowBox[{"Spp", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FpgR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "xp"}], ")"}], 
       RowBox[{"5", "/", "2"}]], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Spp", "[", 
        RowBox[{"x", ",", "y", ",", "cR"}], "]"}], " ", 
       RowBox[{"Spp", "[", 
        RowBox[{"xp", ",", 
         RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
      RowBox[{"Spp", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FplR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "xp"}], ")"}], 
       RowBox[{"5", "/", "2"}]], 
      SuperscriptBox["y", "5"]], 
     FractionBox[
      RowBox[{
       RowBox[{"Spp", "[", 
        RowBox[{"xp", ",", "y", ",", "cR"}], "]"}], " ", 
       RowBox[{"Spp", "[", 
        RowBox[{"x", ",", 
         RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
      RowBox[{"Spp", "[", 
       RowBox[{"y", ",", 
        RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Now", " ", "define", " ", "piecewise", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FmL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"FmgL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"FmlL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FpL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"FpgL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"FplL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FmR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"FmgR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"FmlR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FpR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"FpgR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"FplR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Derivatives", " ", "of", " ", "these", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFmgL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FmgL", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFmlL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FmlL", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFpgL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FpgL", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFplL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FplL", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFmgR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FmgR", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFmlR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FmlR", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFpgR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FpgR", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFplR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "z"], " ", 
      RowBox[{"FplR", "[", 
       RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Now", " ", "define", " ", "piecewise", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFmL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"dFmgL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"dFmlL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFpL", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"dFpgL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"dFplL", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFmR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"dFmgR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"dFmlR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dFpR", "[", 
     RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
    RowBox[{"\[Piecewise]", GridBox[{
       {
        RowBox[{"dFpgR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "\[GreaterEqual]", "xp"}]},
       {
        RowBox[{"dFplR", "[", 
         RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
        RowBox[{"x", "<", "xp"}]}
      }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"0", "MI", " ", "Hpm", " ", "Loop"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "Testing", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"FmR", "[", 
        RowBox[{"y", ",", "y", ",", "y", ",", "cR"}], "]"}], 
       FractionBox[
        SuperscriptBox["y", "5"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "1", ",", "25"}], "}"}]}], "]"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"plotIR", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"FmR", "[", 
        RowBox[{"y", ",", "y", ",", "y", ",", "cL"}], "]"}], 
       FractionBox[
        SuperscriptBox["y", "5"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.49424876162568*^9, 3.494248820195053*^9}, {
  3.494248868556808*^9, 3.494248869847342*^9}, {3.494248928564393*^9, 
  3.4942489304218884`*^9}, {3.494249091797803*^9, 3.494249104346442*^9}, {
  3.494273920425478*^9, 3.494273921701664*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8Vf8fB3BSycqKVAoZKVFWZL0bRJkhKyQ7694rJBQiq2SUCmVkRPa+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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.001, 0.4}, {-275.40290462054975`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.494248791900745*^9, 3.494248823239079*^9}, {
   3.494248870473147*^9, 3.49424887845615*^9}, 3.494248930722455*^9, 
   3.494249126021949*^9, 3.4942491571403713`*^9, {3.494249200449131*^9, 
   3.494249225668598*^9}, {3.4942492708554277`*^9, 3.494249290870023*^9}, 
   3.49427401940322*^9, 3.497663740924708*^9, 3.499135357467701*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plotIR", ",", "plotfull"}], "]"}]], "Input",
 CellChangeTimes->{{3.494248826150247*^9, 3.4942488540302134`*^9}, {
  3.494248954565838*^9, 3.494248991637991*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8Vf8fB3BSycqKVAoZKVFWZL0bRJkhKyQ7694rJBQiq2SUCmVkRPa+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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0VV8bB3BDUpLIkPSjyFRSiJTpyUzGkCQkmTLeczMkijJHmVKhZJbM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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.001, 0.4}, {-275.40290462054975`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.494249130612431*^9, 3.494249166360222*^9, {3.4942492005129833`*^9, 
   3.49424922574002*^9}, {3.4942492709092913`*^9, 3.494249290938122*^9}, 
   3.494274019458873*^9, 3.497663740979124*^9}]
}, Open  ]],

Cell[TextData[{
 "Conclusion: the diagram is completely well behaved in the IR, it doesn't \
look like there's any pole to subtract off the IR. However, the point is that \
the region below approx. 0.1 is well matched by the flavor-diagonalizable \
zero modes and so really are not physical contributions. The difference \
between the IR and full calculation is in the \"UV\" region so this is not \
physical. The UV is defined as the region above the scale set by the problem, \
which is MwR'. For a good approximation I should be able to just integrate \
from 0.08 onward. If I want to nitpick I can actually do a subtraction.\n\n",
 StyleBox["2 Nov 2010",
  FontWeight->"Bold"],
 ": This was one of the first integrals that I re-did. I was lazy and didn't \
care about doing the full subtraction. The whole thing is very suppressed \
anyway. "
}], "Text",
 CellChangeTimes->{{3.494250129374855*^9, 3.4942501870140877`*^9}, {
  3.494250470829706*^9, 3.494250504371471*^9}, {3.494250544549494*^9, 
  3.494250586052581*^9}, {3.4942506805537148`*^9, 3.494250713305004*^9}, {
  3.497663758494421*^9, 3.4976637900195427`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The integral", "Section",
 CellChangeTimes->{{3.49425096968742*^9, 3.494250971467852*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "the", " ", "warp", " ", "factor"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "16"}]]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "warp", " ", "factor", " ", "that", " ", "appears", " ", "in", " ", 
    "functions"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MwRp", "=", ".08"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "internal", " ", "propagator", " ", "cL", " ", "and", " ", 
    "cR"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cL", "=", ".55"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cR", "=", 
    RowBox[{"-", ".55"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "shorthand", " ", "for", " ", "Bessel", " ", "functions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Will", " ", "make", " ", "it", " ", "easier", " ", "to", " ", "plug", " ",
     "in", " ", "IR", " ", "limit"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bI", "[", 
   RowBox[{"a_", ",", "x_"}], "]"}], ":=", 
  RowBox[{"BesselI", "[", 
   RowBox[{"a", ",", "x"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bK", "[", 
    RowBox[{"a_", ",", "x_"}], "]"}], ":=", 
   RowBox[{"BesselK", "[", 
    RowBox[{"a", ",", "x"}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "Auxilliary", " ", "S", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S", "[", 
   RowBox[{"x_", ",", "cx_", ",", "xp_", ",", "cxp_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cx", ",", "x"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cx", ",", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Spp", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Spm", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "-", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Smp", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "-", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Smm", "[", 
    RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"S", "[", 
    RowBox[{"x", ",", 
     RowBox[{"c", "-", 
      RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
     RowBox[{"c", "-", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "Auxilliary", " ", "T", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x_", ",", "cx_", ",", "xp_", ",", "cxp_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cx", ",", "x"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"bI", "[", 
     RowBox[{"cxp", ",", "xp"}], "]"}], 
    RowBox[{"bK", "[", 
     RowBox[{"cx", ",", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tpm", "[", 
   RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"T", "[", 
   RowBox[{"x", ",", 
    RowBox[{"c", "+", 
     RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
    RowBox[{"c", "-", 
     RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tmp", "[", 
    RowBox[{"x_", ",", "xp_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"T", "[", 
    RowBox[{"x", ",", 
     RowBox[{"c", "-", 
      RowBox[{"1", "/", "2"}]}], ",", "xp", ",", 
     RowBox[{"c", "+", 
      RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"F", "-", 
    RowBox[{"tilde", " ", "functions", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"pull", " ", "out", " ", "R"}], ",", " ", 
       RowBox[{"R", "'"}], ",", " ", 
       RowBox[{"and", " ", "i"}]}], ")"}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "xp"}], ")"}], 
     RowBox[{"5", "/", "2"}]], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Smm", "[", 
      RowBox[{"x", ",", "y", ",", "cL"}], "]"}], " ", 
     RowBox[{"Smm", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
    RowBox[{"Smm", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cL"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmlL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "xp"}], ")"}], 
     RowBox[{"5", "/", "2"}]], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Smm", "[", 
      RowBox[{"xp", ",", "y", ",", "cL"}], "]"}], " ", 
     RowBox[{"Smm", "[", 
      RowBox[{"x", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
    RowBox[{"Smm", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cL"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FpgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Tpm", "[", 
      RowBox[{"x", ",", "y", ",", "cL"}], "]"}], " ", 
     RowBox[{"Tpm", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
    RowBox[{"Smm", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{"FplL", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "xp"}], ")"}], 
       RowBox[{"5", "/", "2"}]]}], 
     SuperscriptBox["y", "5"]], 
    FractionBox[
     RowBox[{
      RowBox[{"Tpm", "[", 
       RowBox[{"xp", ",", "y", ",", "cL"}], "]"}], " ", 
      RowBox[{"Tpm", "[", 
       RowBox[{"x", ",", 
        RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]}], 
     RowBox[{"Smm", "[", 
      RowBox[{"y", ",", 
       RowBox[{"w", " ", "y"}], ",", "cL"}], "]"}]]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Tmp", "[", 
      RowBox[{"x", ",", "y", ",", "cR"}], "]"}], " ", 
     RowBox[{"Tmp", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
    RowBox[{"Spp", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cR"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmlR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Tmp", "[", 
      RowBox[{"xp", ",", "y", ",", "cR"}], "]"}], " ", 
     RowBox[{"Tmp", "[", 
      RowBox[{"x", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
    RowBox[{"Spp", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cR"}], 
     "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FpgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "xp"}], ")"}], 
     RowBox[{"5", "/", "2"}]], 
    SuperscriptBox["y", "5"]], 
   FractionBox[
    RowBox[{
     RowBox[{"Spp", "[", 
      RowBox[{"x", ",", "y", ",", "cR"}], "]"}], " ", 
     RowBox[{"Spp", "[", 
      RowBox[{"xp", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
    RowBox[{"Spp", "[", 
     RowBox[{"y", ",", 
      RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{"FplR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", "xp"}], ")"}], 
      RowBox[{"5", "/", "2"}]], 
     SuperscriptBox["y", "5"]], 
    FractionBox[
     RowBox[{
      RowBox[{"Spp", "[", 
       RowBox[{"xp", ",", "y", ",", "cR"}], "]"}], " ", 
      RowBox[{"Spp", "[", 
       RowBox[{"x", ",", 
        RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]}], 
     RowBox[{"Spp", "[", 
      RowBox[{"y", ",", 
       RowBox[{"w", " ", "y"}], ",", "cR"}], "]"}]]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Now", " ", "define", " ", "piecewise", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"FmgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"FmlL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FpL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"FpgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"FplL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FmR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"FmgR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"FmlR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FpR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{"FpgR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "\[GreaterEqual]", "xp"}]},
      {
       RowBox[{"FplR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "<", "xp"}]}
     }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Derivatives", " ", "of", " ", "these", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmgL", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmlL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmlL", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFpgL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FpgL", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dFplL", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "z"], " ", 
     RowBox[{"FplL", "[", 
      RowBox[{"y", ",", "z", ",", "xp", ",", "cL"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmgR", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmlR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FmlR", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFpgR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"FpgR", "[", 
     RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dFplR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "z"], " ", 
     RowBox[{"FplR", "[", 
      RowBox[{"y", ",", "z", ",", "xp", ",", "cR"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"z", "\[Rule]", "x"}], "}"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Now", " ", "define", " ", "piecewise", " ", "functions"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"dFmgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"dFmlL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFpL", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cL_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"dFpgL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"dFplL", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cL"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dFmR", "[", 
   RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"dFmgR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "\[GreaterEqual]", "xp"}]},
     {
      RowBox[{"dFmlR", "[", 
       RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
      RowBox[{"x", "<", "xp"}]}
    }]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dFpR", "[", 
    RowBox[{"y_", ",", "x_", ",", "xp_", ",", "cR_"}], "]"}], ":=", 
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{"dFpgR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "\[GreaterEqual]", "xp"}]},
      {
       RowBox[{"dFplR", "[", 
        RowBox[{"y", ",", "x", ",", "xp", ",", "cR"}], "]"}], 
       RowBox[{"x", "<", "xp"}]}
     }]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"0", "MI", " ", "Hpm", " ", "Loop"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FmR", "[", 
     RowBox[{"y", ",", "y", ",", "y", ",", "cR"}], "]"}], 
    FractionBox[
     SuperscriptBox["y", "5"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", ".08", ",", "\[Infinity]"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FpL", "[", 
     RowBox[{"y", ",", "y", ",", "y", ",", "cL"}], "]"}], 
    FractionBox[
     SuperscriptBox["y", "5"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", ".08", ",", "\[Infinity]"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4942509837774963`*^9, 3.494251016734736*^9}, {
  3.4942740126594048`*^9, 3.494274096130589*^9}, {3.494274657356008*^9, 
  3.494274661615082*^9}, {3.494274701951968*^9, 3.494274728744652*^9}}],

Cell[BoxData[
 RowBox[{"-", "1.5724089467308748`"}]], "Output",
 CellChangeTimes->{{3.494250994323093*^9, 3.4942510173832293`*^9}, 
   3.49427401956287*^9, {3.4942740659762917`*^9, 3.494274096548416*^9}, {
   3.494274658314618*^9, 3.494274662094092*^9}, {3.494274712593603*^9, 
   3.494274729153077*^9}, 3.497663742278049*^9, 3.499135360859281*^9}],

Cell[BoxData[
 RowBox[{"-", "1.5724089467308746`"}]], "Output",
 CellChangeTimes->{{3.494250994323093*^9, 3.4942510173832293`*^9}, 
   3.49427401956287*^9, {3.4942740659762917`*^9, 3.494274096548416*^9}, {
   3.494274658314618*^9, 3.494274662094092*^9}, {3.494274712593603*^9, 
   3.494274729153077*^9}, 3.497663742278049*^9, 3.499135360924597*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FpL", "[", 
     RowBox[{"y", ",", "y", ",", "y", ",", ".667"}], "]"}], 
    FractionBox[
     SuperscriptBox["y", "5"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", ".08", ",", "\[Infinity]"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FpL", "[", 
     RowBox[{"y", ",", "y", ",", "y", ",", ".587"}], "]"}], 
    FractionBox[
     SuperscriptBox["y", "5"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", ".08", ",", "\[Infinity]"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FpL", "[", 
     RowBox[{"y", ",", "y", ",", "y", ",", ".537"}], "]"}], 
    FractionBox[
     SuperscriptBox["y", "5"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", "MwRp", ")"}], "2"]}], ")"}], "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", ".08", ",", "\[Infinity]"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.499135379295703*^9, 3.499135393575933*^9}}],

Cell[BoxData[
 RowBox[{"-", "1.3883241343014903`"}]], "Output",
 CellChangeTimes->{3.499135394228921*^9}],

Cell[BoxData[
 RowBox[{"-", "1.4704020781769458`"}]], "Output",
 CellChangeTimes->{3.499135394293597*^9}],

Cell[BoxData[
 RowBox[{"-", "1.659579962942837`"}]], "Output",
 CellChangeTimes->{3.499135394366721*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{584, 691},
WindowMargins->{{Automatic, 257}, {Automatic, 12}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (March 13, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 308, 9, 80, "Title"],
Cell[901, 34, 550, 11, 86, "Text"],
Cell[1454, 47, 214, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[1693, 55, 98, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[1816, 60, 19910, 595, 1540, "Input"],
Cell[21729, 657, 7674, 131, 227, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29452, 794, 99, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[29576, 799, 20556, 590, 1565, "Input"],
Cell[50135, 1391, 7592, 129, 227, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57764, 1525, 209, 4, 27, "Input"],
Cell[57976, 1531, 14446, 244, 227, "Output"]
}, Open  ]],
Cell[72437, 1778, 1123, 18, 161, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73597, 1801, 96, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[73718, 1806, 18423, 560, 1431, "Input"],
Cell[92144, 2368, 348, 5, 27, "Output"],
Cell[92495, 2375, 348, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92880, 2385, 1522, 48, 149, "Input"],
Cell[94405, 2435, 105, 2, 27, "Output"],
Cell[94513, 2439, 105, 2, 27, "Output"],
Cell[94621, 2443, 104, 2, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
