(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    172252,       3677]
NotebookOptionsPosition[    168809,       3557]
NotebookOutlinePosition[    169201,       3574]
CellTagsIndexPosition[    169158,       3571]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["1xMI Z Loop: alignment", "Title",
 CellChangeTimes->{{3.496442700755785*^9, 3.49644270591714*^9}, {
  3.4964427443571663`*^9, 3.496442750903678*^9}, {3.497662287107358*^9, 
  3.497662292191019*^9}}],

Cell[TextData[{
 "Flip Tanedo\n18 October 2010\n(Corrections and additions from Yuhsin Tsai, \
28 October 2010, now matches)\n2 November 2010: printed, renamed\n6 November \
2010: Y*=2 rerun.\n\nMotivation: In RS FCNC penguin calculations with \
alignment, one must subtract off the \"proportional to the Yukawa\" component \
of the amplitude to get the physical contribution. Consider, for example, the \
",
 StyleBox["Z",
  FontSlant->"Italic"],
 " loop diagram with a single mass insertion in the gauge basis. The flavor \
structure is carried in (1) the Yukawa insertion and (2) the nonuniversality \
of the internal bulk propagators. Only the second effect survives after \
diagonalizing the fermion zero modes to go to the mass basis. \n\nIn this \
notebook we take the output of the RS \[Mu]\[Rule]e\[Gamma] single mass \
insertion (1MI) ",
 StyleBox["Z ",
  FontSlant->"Italic"],
 "loop diagram and extract the physical amplitude by diagonalizing the \
Yukawa. We will workin the \"minimal model\" where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "cL"], "=", 
    SubscriptBox["f", 
     RowBox[{"-", "cR"}]]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.496442710359098*^9, 3.496442824351499*^9}, {
  3.496443028003955*^9, 3.496443245735446*^9}, {3.497004136262925*^9, 
  3.497004152546648*^9}, {3.497277461806055*^9, 3.497277474914949*^9}, {
  3.497313432398531*^9, 3.4973134498499537`*^9}, {3.4976622989320602`*^9, 
  3.497662303838696*^9}, {3.4980900857065477`*^9, 3.49809009500546*^9}}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.496443294923047*^9, 3.496443301466117*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 CellChangeTimes->{{3.49644325445149*^9, 3.4964432563062897`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Determine the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "c"], TraditionalForm]], "None",
  FormatType->"TraditionalForm"],
 " values in the minimal model"
}], "Subsection",
 CellChangeTimes->{{3.4964432575702553`*^9, 3.4964432861602173`*^9}}],

Cell["\<\
\"What's the muon mass? One seven-seven-seven, like the casino.\" - Yuval
All mass scales are in Gev\
\>", "Text",
 CellChangeTimes->{{3.4964435671749573`*^9, 3.496443582634804*^9}, {
  3.496443775105873*^9, 3.4964437802075443`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Ys", "=", "2"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Can", " ", "relax", " ", "this", " ", "by", " ", "uncommenting", " ", 
    "next", " ", "line"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Clear", "[", "Ys", "]"}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"w", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "16"}]]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Warp", " ", "factor"}], ",", " ", 
    RowBox[{"R", "/", 
     RowBox[{"R", "'"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Me", "=", 
   RowBox[{"511.", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], " ", "GeV"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M\[Mu]", "=", 
   RowBox[{".105", " ", "GeV"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M\[Tau]", "=", 
   RowBox[{"1.777", " ", "GeV"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Mt", " ", "=", " ", 
    RowBox[{"173.1", " ", "GeV"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fe", " ", "=", " ", 
   SqrtBox[
    FractionBox["Me", 
     RowBox[{"Mt", " ", "Ys"}]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f\[Mu]", " ", "=", "  ", 
   SqrtBox[
    FractionBox["M\[Mu]", 
     RowBox[{"Mt", " ", "Ys"}]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f\[Tau]", " ", "=", "  ", 
    SqrtBox[
     FractionBox["M\[Tau]", 
      RowBox[{"Mt", " ", "Ys"}]]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"InverseFunction", "::", "\"\<ifun\>\""}], ",", 
   RowBox[{"Solve", "::", "\"\<ifun\>\""}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ce", "=", 
   RowBox[{"c", "/.", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"fe", "\[Equal]", 
        SqrtBox[
         FractionBox[
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], 
          RowBox[{"1", "-", 
           SuperscriptBox["w", 
            RowBox[{"1", "-", 
             RowBox[{"2", "c"}]}]]}]]]}], ",", "c"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c\[Mu]", "=", 
   RowBox[{"c", "/.", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"f\[Mu]", "\[Equal]", 
        SqrtBox[
         FractionBox[
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], 
          RowBox[{"1", "-", 
           SuperscriptBox["w", 
            RowBox[{"1", "-", 
             RowBox[{"2", "c"}]}]]}]]]}], ",", "c"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c\[Tau]", "=", 
   RowBox[{"c", "/.", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"f\[Tau]", "\[Equal]", 
        SqrtBox[
         FractionBox[
          RowBox[{"1", "-", 
           RowBox[{"2", "c"}]}], 
          RowBox[{"1", "-", 
           SuperscriptBox["w", 
            RowBox[{"1", "-", 
             RowBox[{"2", "c"}]}]]}]]]}], ",", "c"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"ce", ",", "c\[Mu]", ",", "c\[Tau]"}], "}"}]}], "Input",
 CellChangeTimes->{{3.496443432982902*^9, 3.4964434907706633`*^9}, {
   3.496443522860876*^9, 3.496443564331319*^9}, {3.496443789944088*^9, 
   3.496443801455855*^9}, {3.49644383168923*^9, 3.49644383183891*^9}, {
   3.49644418860485*^9, 3.496444258172905*^9}, {3.4964443072567987`*^9, 
   3.496444337214834*^9}, {3.496444369426982*^9, 3.496444527315919*^9}, {
   3.496444591434721*^9, 3.496444697268614*^9}, {3.4964447363221903`*^9, 
   3.496444798728826*^9}, {3.4964455437864027`*^9, 3.4964455807138844`*^9}, {
   3.497290450425643*^9, 3.4972904518242197`*^9}, 3.498090120996768*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6673623717475314`", ",", "0.5860901779844163`", ",", 
   "0.5371898610581016`"}], "}"}]], "Output",
 CellChangeTimes->{{3.496445565975617*^9, 3.496445582010763*^9}, {
   3.496770039092507*^9, 3.496770047111945*^9}, 3.4969386509633417`*^9, 
   3.4969641766911507`*^9, 3.497004160428399*^9, 3.497275437326357*^9, 
   3.497275529198824*^9, 3.497309458449871*^9, 3.497310861100849*^9, 
   3.4976624079689913`*^9, {3.49809010797895*^9, 3.498090149059435*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading data", "Subsection",
 CellChangeTimes->{{3.496594075297305*^9, 3.4965940809522943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "List", " ", "of", " ", "y", " ", "values", " ", "that", " ", "are", " ", 
    "sampled"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"yvals1", "=", 
     RowBox[{"{", 
      RowBox[{".01", ",", ".1", ",", ".2", ",", ".5", ",", ".75"}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yvals2", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1.5", ",", "2", ",", "2.5", ",", "3"}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yvals3", "=", 
     RowBox[{"{", 
      RowBox[{"3.5", ",", "4", ",", "4.5", ",", "5", ",", "7"}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yvals4", "=", 
     RowBox[{"{", 
      RowBox[{"9", ",", "11", ",", "14", ",", "17", ",", "20"}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"yvals", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"yvals1", ",", "yvals2", ",", "yvals3", ",", "yvals4"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.496594108473196*^9, 3.496594116985736*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.01`", ",", "0.1`", ",", "0.2`", ",", "0.5`", ",", "0.75`", ",", "1", ",",
    "1.5`", ",", "2", ",", "2.5`", ",", "3", ",", "3.5`", ",", "4", ",", 
   "4.5`", ",", "5", ",", "7", ",", "9", ",", "11", ",", "14", ",", "17", ",",
    "20"}], "}"}]], "Output",
 CellChangeTimes->{
  3.4965942152879963`*^9, {3.496770042035317*^9, 3.496770047148203*^9}, 
   3.4969386510162907`*^9, 3.496964176719542*^9, 3.497004160496314*^9, {
   3.49727552200007*^9, 3.497275529228223*^9}, 3.4973094585022697`*^9, 
   3.4973108611309967`*^9, 3.4976624080013657`*^9, 3.498090108016863*^9, 
   3.4980901490928307`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1501: cL, cR = e,e", "Subsubsection",
 CellChangeTimes->{{3.49659413742268*^9, 3.496594139274066*^9}, {
  3.496594957795102*^9, 3.496594965950172*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1501a", "=", 
   RowBox[{"{", 
    RowBox[{"0.000251202", ",", 
     RowBox[{"-", "0.00117664"}], ",", 
     RowBox[{"-", "0.00800947"}], ",", 
     RowBox[{"-", "0.0530235"}], ",", 
     RowBox[{"-", "0.0185012"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1501b", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00271313"}], ",", "0.00436796", ",", "0.00565126", ",", 
     "0.00150038", ",", 
     RowBox[{"-", "0.00508604"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1501c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0104278"}], ",", 
     RowBox[{"-", "0.0136782"}], ",", 
     RowBox[{"-", "0.0151063"}], ",", 
     RowBox[{"-", "0.0152913"}], ",", 
     RowBox[{"-", "0.011784"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1501d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00828608"}], ",", 
     RowBox[{"-", "0.0059947"}], ",", 
     RowBox[{"-", "0.00394747"}], ",", 
     RowBox[{"-", "0.00278376"}], ",", 
     RowBox[{"-", "0.00206346"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1501", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1501a", ",", "r1501b", ",", "r1501c", ",", "r1501d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1501", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1501"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1501", "=", 
   RowBox[{"Interpolation", "[", "Run1501", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1501", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1501", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mee", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1501", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594143896886*^9, 3.4965942079044456`*^9}, 
   3.4965944147753973`*^9, {3.496597079736862*^9, 3.4965970837541428`*^9}, {
   3.496597302782995*^9, 3.4965973033461313`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, 0.00025120668853285174`}, {
      0.016131291231986936`, 0.0003097781990487932}, {0.022262174504790202`, 
      0.00034470922387689804`}, {0.028393057777593468`, 
      0.0003562024433618031}, {0.03452394105039673, 0.0003444605378481447}, {
      0.040654824323199994`, 0.0003096861876805603}, {0.046785707596003256`, 
      0.0002520820732036858}, {0.05291659086880652, 
      0.00017185087476215884`}, {0.05904747414160978, 
      0.00006919527270061576}, {
      0.06517835741441305, -0.00005568205263630616}, {
      0.07130924068721631, -0.00020257842090397088`}, {
      0.07744012396001958, -0.0003712911517577411}, {
      0.08357100723282285, -0.0005616175648529805}, {
      0.0897018905056261, -0.0007733549798450514}, {
      0.09583277377842937, -0.0010063007163893182`}, {
      0.1080945403240359, -0.0015350064327558895`}, {
      0.11422542359683915`, -0.001830361051888921}, {
      0.12035630686964242`, -0.0021461132711956014`}, {
      0.13261807341524895`, -0.002837999788951358}, {
      0.1387489566880522, -0.0032137287267111608`}, {
      0.1448798399608555, -0.003609044543266067}, {
      0.15714160650646203`, -0.004457626091382633}, {
      0.16327248977926528`, -0.004910486462255019}, {
      0.16940337305206854`, -0.005382122990543961}, {
      0.18166513959767508`, -0.0063809137979929575`}, {
      0.20618867268888813`, -0.008594891366725574}, {
      0.2123195559616914, -0.009192285947280568}, {
      0.21845043923449464`, -0.00980683524249501}, {
      0.23071220578010118`, -0.011086587255523736`}, {
      0.25523573887131423`, -0.013843029922330684`}, {
      0.2613666221441175, -0.014571987170511523`}, {
      0.26749750541692074`, -0.015316477690594722`}, {
      0.2797592719625273, -0.016851247825089677`}, {
      0.3042828050537404, -0.020098269421743947`}, {
      0.31041368832654365`, -0.02094581779549387}, {
      0.3165445715993469, -0.02180727799838907}, {
      0.3288063381449534, -0.02357112317023673}, {
      0.3495494647601595, -0.026688669052259993`}}], LineBox[CompressedData["
1:eJwV13k8VN3/APAhIcSYsY4iipQlEqnkc5CtVSklKmvWLGMZKWTrsc5kKSnK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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.000251202}, {0.1, -0.00117664}, {0.2, -0.00800947}, {
     0.5, -0.0530235}, {0.75, -0.0185012}, {1., -0.00271313}, {1.5, 
     0.00436796}, {2., 0.00565126}, {2.5, 0.00150038}, {3., -0.00508604}, {
     3.5, -0.0104278}, {4., -0.0136782}, {4.5, -0.0151063}, {
     5., -0.0152913}, {7., -0.011784}, {9., -0.00828608}, {11., -0.0059947}, {
     14., -0.00394747}, {17., -0.00278376}, {20., -0.00206346}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.026688669052259993`, 0.005855472537749587}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.496594210131241*^9, 3.4965942164893427`*^9}, 
   3.496594415134659*^9, 3.496597083987442*^9, 3.4965973040712347`*^9, 
   3.496770047748787*^9, 3.496938651394006*^9, 3.4969641768784523`*^9, 
   3.497004160665122*^9, {3.497275528045898*^9, 3.4972755292986403`*^9}, 
   3.497309458659904*^9, 3.497310861180525*^9, 3.497662408135096*^9, 
   3.498090108531135*^9, 3.4980901491555862`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.11273569710119061`"}]], "Output",
 CellChangeTimes->{{3.496594210131241*^9, 3.4965942164893427`*^9}, 
   3.496594415134659*^9, 3.496597083987442*^9, 3.4965973040712347`*^9, 
   3.496770047748787*^9, 3.496938651394006*^9, 3.4969641768784523`*^9, 
   3.497004160665122*^9, {3.497275528045898*^9, 3.4972755292986403`*^9}, 
   3.497309458659904*^9, 3.497310861180525*^9, 3.497662408135096*^9, 
   3.498090108531135*^9, 3.498090149164528*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1502: cL, cR = e,mu", "Subsubsection",
 CellChangeTimes->{{3.496594294743198*^9, 3.496594296879119*^9}, {
  3.496594974213759*^9, 3.4965949766868677`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1502a", "=", 
   RowBox[{"{", 
    RowBox[{"0.000193263", ",", "0.0741812", ",", 
     RowBox[{"-", "0.141326"}], ",", "0.0263548", ",", "0.0217027"}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1502b", "=", 
   RowBox[{"{", 
    RowBox[{"0.0337233", ",", "0.0219748", ",", "0.00367678", ",", 
     RowBox[{"-", "0.000482105"}], ",", 
     RowBox[{"-", "0.00647899"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1502c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0114324"}], ",", 
     RowBox[{"-", "0.0144071"}], ",", 
     RowBox[{"-", "0.0156846"}], ",", 
     RowBox[{"-", "0.0157309"}], ",", 
     RowBox[{"-", "0.011936"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1502d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00835235"}], ",", 
     RowBox[{"-", "0.00602915"}], ",", 
     RowBox[{"-", "0.00396457"}], ",", 
     RowBox[{"-", "0.00279255"}], ",", 
     RowBox[{"-", "0.00206888"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1502", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1502a", ",", "r1502b", ",", "r1502c", ",", "r1502d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1502", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1502"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1502", "=", 
   RowBox[{"Interpolation", "[", "Run1502", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1502", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1502", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Memu", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1502", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594302557041*^9, 3.496594367409113*^9}, 
   3.496594411885054*^9, {3.496597086503883*^9, 3.496597092730033*^9}, {
   3.4965973066317043`*^9, 3.4965973084182663`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, 0.00019449337186447369`}, {
      0.014244399065028798`, 0.01225972843920885}}], LineBox[CompressedData["
1:eJwV1Xc4Vf8fAPBrj6x7L8W9RsleuURCzltIZEYolOxRlJ2MzO617s1ISooi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      "]], 
     LineBox[{{0.13950843343101924`, 0.01225972843920885}, {
      0.1448798399608555, 0.0009341308503204304}, {
      0.15702729441942673`, -0.0268407534114089}}], 
     LineBox[{{0.4931579151818648, -0.0268407534114089}, {
      0.49542905757603256`, -0.009832296407992252}, {0.49945650955078025`, 
      0.01225972843920885}}]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.000193263}, {0.1, 0.0741812}, {0.2, -0.141326}, {0.5, 
     0.0263548}, {0.75, 0.0217027}, {1., 0.0337233}, {1.5, 0.0219748}, {2., 
     0.00367678}, {2.5, -0.000482105}, {3., -0.00647899}, {3.5, -0.0114324}, {
     4., -0.0144071}, {4.5, -0.0156846}, {5., -0.0157309}, {7., -0.011936}, {
     9., -0.00835235}, {11., -0.00602915}, {14., -0.00396457}, {
     17., -0.00279255}, {20., -0.00206888}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.0268407534114089, 0.01225972843920885}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.496594368982543*^9, 3.496594412319044*^9, {3.496597090337912*^9, 
   3.496597092978875*^9}, 3.4965973087881804`*^9, 3.4967700479846087`*^9, 
   3.496938651538636*^9, 3.4969641769665117`*^9, 3.497004160811061*^9, 
   3.497275529432435*^9, 3.497309458758833*^9, 3.49731086122011*^9, 
   3.497662408198762*^9, 3.498090108795126*^9, 3.498090149203765*^9}],

Cell[BoxData[
 RowBox[{"-", "0.10010388648214297`"}]], "Output",
 CellChangeTimes->{
  3.496594368982543*^9, 3.496594412319044*^9, {3.496597090337912*^9, 
   3.496597092978875*^9}, 3.4965973087881804`*^9, 3.4967700479846087`*^9, 
   3.496938651538636*^9, 3.4969641769665117`*^9, 3.497004160811061*^9, 
   3.497275529432435*^9, 3.497309458758833*^9, 3.49731086122011*^9, 
   3.497662408198762*^9, 3.498090108795126*^9, 3.498090149209556*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1503: cL, cR = e,tau", "Subsubsection",
 CellChangeTimes->{{3.496594294743198*^9, 3.496594296879119*^9}, {
  3.496594402824727*^9, 3.496594403908146*^9}, {3.496594979416728*^9, 
  3.496594981134101*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1503a", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.000473597", ",", "0.00783814", ",", "0.0238219", ",", "0.0243835", ",",
      "0.0334523"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1503b", "=", 
   RowBox[{"{", 
    RowBox[{"0.0271977", ",", "0.0183475", ",", "0.0123358", ",", 
     RowBox[{"-", "0.00123996"}], ",", 
     RowBox[{"-", "0.00734991"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1503c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0121496"}], ",", 
     RowBox[{"-", "0.0149973"}], ",", 
     RowBox[{"-", "0.0160907"}], ",", 
     RowBox[{"-", "0.0160165"}], ",", 
     RowBox[{"-", "0.0120329"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1503d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00839438"}], ",", 
     RowBox[{"-", "0.0060512"}], ",", 
     RowBox[{"-", "0.00397513"}], ",", 
     RowBox[{"-", "0.00279821"}], ",", 
     RowBox[{"-", "0.00207231"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1503", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1503a", ",", "r1503b", ",", "r1503c", ",", "r1503d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1503", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1503"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1503", "=", 
   RowBox[{"Interpolation", "[", "Run1503", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1503", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1503", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Metau", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1503", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594302557041*^9, 3.496594367409113*^9}, {
  3.4965944095728407`*^9, 3.4965944726500263`*^9}, {3.4965971231767387`*^9, 
  3.4965971300274267`*^9}, {3.49659731188933*^9, 3.496597313683413*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, 0.0004736038402012501}, {
      0.016131291231986936`, 0.0006087563555811221}, {0.022262174504790202`, 
      0.000807102739949655}, {0.028393057777593468`, 
      0.0010663700730717584`}, {0.03452394105039673, 
      0.0013842854347123406`}, {0.040654824323199994`, 
      0.0017585759046363104`}, {0.046785707596003256`, 
      0.002186968562608577}, {0.05291659086880652, 0.002667190488394049}, {
      0.05904747414160978, 0.0031969687617576367`}, {0.06517835741441305, 
      0.003774030462464247}, {0.07130924068721631, 0.004396102670278788}, {
      0.08357100723282285, 0.005766186926291307}, {0.0897018905056261, 
      0.006509653134019099}, {0.09583277377842937, 0.00728903816791446}, {
      0.1080945403240359, 0.00894647303326752}, {0.11422542359683915`, 
      0.009819977024255038}, {0.12035630686964242`, 0.01072030816046976}, {
      0.1319012471581179, 0.012482919509349917`}}], LineBox[CompressedData["
1:eJwV1Xk4VV0XAPBrnrkDMlReMitDipLcZUpFGghFyJghIVMy5IZc0z2iVIZQ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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.000473597}, {0.1, 0.00783814}, {0.2, 0.0238219}, {0.5, 
     0.0243835}, {0.75, 0.0334523}, {1., 0.0271977}, {1.5, 0.0183475}, {2., 
     0.0123358}, {2.5, -0.00123996}, {3., -0.00734991}, {3.5, -0.0121496}, {
     4., -0.0149973}, {4.5, -0.0160907}, {5., -0.0160165}, {7., -0.0120329}, {
     9., -0.00839438}, {11., -0.0060512}, {14., -0.00397513}, {
     17., -0.00279821}, {20., -0.00207231}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.016168313501095342`, 0.012482919509349917`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496597130314485*^9, 
  3.496597314149205*^9, 3.4967700481203403`*^9, 3.496938651771634*^9, 
  3.496964177083392*^9, 3.497004160910924*^9, 3.497275529649975*^9, 
  3.497309458807123*^9, 3.497310861265526*^9, 3.4976624082484922`*^9, 
  3.498090108834487*^9, 3.498090149254039*^9}],

Cell[BoxData[
 RowBox[{"-", "0.10273483151041678`"}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496597130314485*^9, 
  3.496597314149205*^9, 3.4967700481203403`*^9, 3.496938651771634*^9, 
  3.496964177083392*^9, 3.497004160910924*^9, 3.497275529649975*^9, 
  3.497309458807123*^9, 3.497310861265526*^9, 3.4976624082484922`*^9, 
  3.498090108834487*^9, 3.498090149260792*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1504: cL, cR = mu,mu", "Subsubsection",
 CellChangeTimes->{{3.496594294743198*^9, 3.496594296879119*^9}, {
   3.496594402824727*^9, 3.496594403908146*^9}, 3.4965945104205523`*^9, {
   3.496594984478607*^9, 3.496594990927355*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1504a", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.0000177048", ",", "0.00320094", ",", "0.0426578", ",", "0.000569322", 
     ",", "0.000459247"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1504b", "=", 
   RowBox[{"{", 
    RowBox[{"0.00243751", ",", "0.00706133", ",", 
     RowBox[{"-", "0.00245561"}], ",", 
     RowBox[{"-", "0.00317398"}], ",", 
     RowBox[{"-", "0.00807166"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1504c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0124061"}], ",", 
     RowBox[{"-", "0.0151551"}], ",", 
     RowBox[{"-", "0.0162728"}], ",", 
     RowBox[{"-", "0.0161782"}], ",", 
     RowBox[{"-", "0.0120898"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1504d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0084191"}], ",", 
     RowBox[{"-", "0.00606438"}], ",", 
     RowBox[{"-", "0.00398112"}], ",", 
     RowBox[{"-", "0.00280156"}], ",", 
     RowBox[{"-", "0.00207448"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1504", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1504a", ",", "r1504b", ",", "r1504c", ",", "r1504d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1504", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1504"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1504", "=", 
   RowBox[{"Interpolation", "[", "Run1504", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1504", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1504", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mmumu", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1504", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594302557041*^9, 3.496594367409113*^9}, {
  3.4965944095728407`*^9, 3.4965944726500263`*^9}, {3.496594513050375*^9, 
  3.4965945628644533`*^9}, {3.496597133865777*^9, 3.496597139944911*^9}, {
  3.496597318106344*^9, 3.4965973196668043`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, 0.00001760386447597316}, {
      0.016131291231986936`, -0.0013603952312762693`}, {
      0.022262174504790202`, -0.002466729024516596}, {
      0.028393057777593468`, -0.00331050534687041}, {
      0.03452394105039673, -0.0039008320299631126`}, {
      0.040654824323199994`, -0.004246816905420113}, {
      0.046785707596003256`, -0.0043575678048668135`}, {
      0.05291659086880652, -0.0042421925599286205`}, {
      0.05904747414160978, -0.0039097990022309344`}, {
      0.06517835741441305, -0.0033694949633991667`}, {
      0.07130924068721631, -0.0026303882750587197`}, {
      0.07744012396001958, -0.0017015867688349945`}, {
      0.08357100723282285, -0.0005921982763533971}, {0.0897018905056261, 
      0.0006886693707606633}, {0.09583277377842937, 0.002131908340881789}, {
      0.10196365705123264`, 0.003728410802384577}, {0.1080945403240359, 
      0.0054690689236436}, {0.11422542359683915`, 0.007344774873033484}, {
      0.12035630686964242`, 0.009346420818928801}, {0.12811740750086228`, 
      0.012096391866814273`}}], LineBox[CompressedData["
1:eJwV1nk4lc8XAPDrWpP1XrIVkT1EkpLMQYoWEUXZd9eWfV+KyCVcS6kvFS22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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.0000177048}, {0.1, 0.00320094}, {0.2, 0.0426578}, {0.5,
      0.000569322}, {0.75, 0.000459247}, {1., 0.00243751}, {1.5, 
     0.00706133}, {2., -0.00245561}, {2.5, -0.00317398}, {3., -0.00807166}, {
     3.5, -0.0124061}, {4., -0.0151551}, {4.5, -0.0162728}, {
     5., -0.0161782}, {7., -0.0120898}, {9., -0.0084191}, {
     11., -0.00606438}, {14., -0.00398112}, {17., -0.00280156}, {
     20., -0.00207448}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.016357016816516128`, 0.012096391866814273`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496597142576992*^9, 3.49659732002321*^9, 3.4967700482371597`*^9, 
  3.496938651902546*^9, 3.496964177167014*^9, 3.497004161012*^9, 
  3.4972755299505463`*^9, 3.4973094588562117`*^9, 3.4973108613151693`*^9, 
  3.49766240828272*^9, 3.498090108879281*^9, 3.4980901493047667`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.12337084658273823`"}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496597142576992*^9, 3.49659732002321*^9, 3.4967700482371597`*^9, 
  3.496938651902546*^9, 3.496964177167014*^9, 3.497004161012*^9, 
  3.4972755299505463`*^9, 3.4973094588562117`*^9, 3.4973108613151693`*^9, 
  3.49766240828272*^9, 3.498090108879281*^9, 3.498090149314248*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1505: cL, cR = mu,tau", "Subsubsection",
 CellChangeTimes->{{3.496594294743198*^9, 3.496594296879119*^9}, {
   3.496594402824727*^9, 3.496594403908146*^9}, 3.4965945104205523`*^9, 
   3.496594588389176*^9, {3.496594993720648*^9, 3.4965949972557907`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1505a", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}], ",", "0.0279186", ",", "0.00199256", ",", 
     RowBox[{"0.1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}], ",", "0.000263671"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1505b", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.00199056", ",", "0.0067588", ",", "0.00495544", ",", "0.00214016", ",",
      
     RowBox[{"-", "0.00501519"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1505c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0131549"}], ",", 
     RowBox[{"-", "0.0157674"}], ",", 
     RowBox[{"-", "0.0166832"}], ",", 
     RowBox[{"-", "0.0164702"}], ",", 
     RowBox[{"-", "0.012187"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1505d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00846155"}], ",", 
     RowBox[{"-", "0.00608654"}], ",", 
     RowBox[{"-", "0.00399148"}], ",", 
     RowBox[{"-", "0.00280721"}], ",", 
     RowBox[{"-", "0.00207769"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1505", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1505a", ",", "r1505b", ",", "r1505c", ",", "r1505d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1505", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1505"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1505", "=", 
   RowBox[{"Interpolation", "[", "Run1505", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1505", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1505", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mmutau", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1505", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594302557041*^9, 3.496594367409113*^9}, {
  3.4965944095728407`*^9, 3.4965944726500263`*^9}, {3.496594513050375*^9, 
  3.4965945628644533`*^9}, {3.4965946074526577`*^9, 3.49659465464955*^9}, {
  3.4965946851683197`*^9, 3.496594709693344*^9}, {3.496597144689336*^9, 
  3.496597148123221*^9}, {3.4965973227616377`*^9, 3.4965973242098713`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, 3.8827010542807905`*^-7}, {
      0.016131291231986936`, 0.004143641422674187}, {0.022262174504790202`, 
      0.007915905188215493}, {0.028393057777593468`, 0.011327421439084023`}, {
      0.03208750283973135, 0.013171973850981449`}}], LineBox[CompressedData["
1:eJwV1nc8ld8fAHB7r3sv4gqRFRpWRnKOzL5kRsseWSl7k4Rc814RFUohmxSV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      "]], 
     LineBox[{{0.17108414781465106`, 0.013171973850981449`}, {
      0.18166513959767508`, 0.00932986207958587}, {
      0.20618867268888813`, -0.000626559934096868}, {
      0.2123195559616914, -0.003274998478485151}, {
      0.21845043923449464`, -0.005966686494551112}, {
      0.23071220578010118`, -0.011438843452297363`}, {
      0.25523573887131423`, -0.022451508644316064`}, {
      0.2613666221441175, -0.025159170536194733`}, {
      0.26749750541692074`, -0.027828146920913628`}, {
      0.2679362732995037, -0.028013538245462377`}}]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 1.*^-7}, {0.1, 0.0279186}, {0.2, 0.00199256}, {0.5, 
     0.0001}, {0.75, 0.000263671}, {1., 0.00199056}, {1.5, 0.0067588}, {2., 
     0.00495544}, {2.5, 0.00214016}, {3., -0.00501519}, {3.5, -0.0131549}, {
     4., -0.0157674}, {4.5, -0.0166832}, {5., -0.0164702}, {7., -0.012187}, {
     9., -0.00846155}, {11., -0.00608654}, {14., -0.00399148}, {
     17., -0.00280721}, {20., -0.00207769}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.028013538245462377`, 0.013171973850981449`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496594711637485*^9, 3.496597148364045*^9, 3.496597324618698*^9, 
  3.496770048354025*^9, 3.496938652072891*^9, 3.496964177251041*^9, 
  3.497004161146879*^9, 3.497275530100603*^9, 3.497309458908051*^9, 
  3.497310861367683*^9, 3.497662408332131*^9, 3.498090108916493*^9, 
  3.498090149354903*^9}],

Cell[BoxData[
 RowBox[{"-", "0.11734164624821443`"}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496594711637485*^9, 3.496597148364045*^9, 3.496597324618698*^9, 
  3.496770048354025*^9, 3.496938652072891*^9, 3.496964177251041*^9, 
  3.497004161146879*^9, 3.497275530100603*^9, 3.497309458908051*^9, 
  3.497310861367683*^9, 3.497662408332131*^9, 3.498090108916493*^9, 
  3.498090149360667*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1506: cL, cR = tau,tau", "Subsubsection",
 CellChangeTimes->{{3.496594294743198*^9, 3.496594296879119*^9}, {
   3.496594402824727*^9, 3.496594403908146*^9}, 3.4965945104205523`*^9, 
   3.496594588389176*^9, 3.4965947413877172`*^9, {3.496594999763895*^9, 
   3.496595002454733*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"r1506a", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2.84787"}], " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]]}], ",", 
    RowBox[{"0.1", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "4"}]]}], ",", 
    RowBox[{"-", "0.000605648"}], ",", 
    RowBox[{"0.1", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}], ",", "0.000924779"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1506b", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.00256537", ",", "0.00655983", ",", "0.00630476", ",", "0.000738219", 
     ",", 
     RowBox[{"-", "0.00620228"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1506c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0116231"}], ",", 
     RowBox[{"-", "0.0147656"}], ",", 
     RowBox[{"-", "0.015958"}], ",", 
     RowBox[{"-", "0.0159363"}], ",", 
     RowBox[{"-", "0.0119832"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1506d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00839094"}], ",", 
     RowBox[{"-", "0.00610624"}], ",", 
     RowBox[{"-", "0.00400191"}], ",", 
     RowBox[{"-", "0.00281288"}], ",", 
     RowBox[{"-", "0.00208118"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1506", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1506a", ",", "r1506b", ",", "r1506c", ",", "r1506d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1506", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1506"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1506", "=", 
   RowBox[{"Interpolation", "[", "Run1506", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1506", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1506", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mtautau", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1506", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594302557041*^9, 3.496594367409113*^9}, {
   3.4965944095728407`*^9, 3.4965944726500263`*^9}, {3.496594513050375*^9, 
   3.4965945628644533`*^9}, {3.4965946074526577`*^9, 3.49659465464955*^9}, {
   3.4965946851683197`*^9, 3.496594709693344*^9}, {3.496594763497452*^9, 
   3.496594834973618*^9}, {3.496597053769968*^9, 3.496597058802019*^9}, 
   3.496597151660163*^9, {3.496597328450976*^9, 3.49659732982623*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2.84787`*^-6"}], ",", "0.00001`", ",", 
   RowBox[{"-", "0.000605648`"}], ",", "0.0001`", ",", "0.000924779`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496594711637485*^9, 3.4965948357692432`*^9, 3.496597060191002*^9, 
  3.496597151854877*^9, 3.496597330189221*^9, 3.496770048557609*^9, 
  3.496938652192073*^9, 3.496964177334568*^9, 3.497004161264083*^9, 
  3.497275530288558*^9, 3.497309458941731*^9, 3.497310861415917*^9, 
  3.4976624083661423`*^9, 3.498090108963482*^9, 3.498090149404138*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VO8XAHBbyG6GMIrIlpAlpch5lULKTkTZd9ki25RCshtRSlRKQkJC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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, -2.84787*^-6}, {0.1, 0.00001}, {0.2, -0.000605648}, {0.5,
      0.0001}, {0.75, 0.000924779}, {1., 0.00256537}, {1.5, 0.00655983}, {2., 
     0.00630476}, {2.5, 0.000738219}, {3., -0.00620228}, {3.5, -0.0116231}, {
     4., -0.0147656}, {4.5, -0.015958}, {5., -0.0159363}, {7., -0.0119832}, {
     9., -0.00839094}, {11., -0.00610624}, {14., -0.00400191}, {
     17., -0.00281288}, {20., -0.00208118}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.01605450502481763, 0.007034505818877804}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496594711637485*^9, 3.4965948357692432`*^9, 3.496597060191002*^9, 
  3.496597151854877*^9, 3.496597330189221*^9, 3.496770048557609*^9, 
  3.496938652192073*^9, 3.496964177334568*^9, 3.497004161264083*^9, 
  3.497275530288558*^9, 3.497309458941731*^9, 3.497310861415917*^9, 
  3.4976624083661423`*^9, 3.498090108963482*^9, 3.49809014940698*^9}],

Cell[BoxData[
 RowBox[{"-", "0.11527983193035728`"}]], "Output",
 CellChangeTimes->{3.496594473290841*^9, 3.496594565392531*^9, 
  3.496594711637485*^9, 3.4965948357692432`*^9, 3.496597060191002*^9, 
  3.496597151854877*^9, 3.496597330189221*^9, 3.496770048557609*^9, 
  3.496938652192073*^9, 3.496964177334568*^9, 3.497004161264083*^9, 
  3.497275530288558*^9, 3.497309458941731*^9, 3.497310861415917*^9, 
  3.4976624083661423`*^9, 3.498090108963482*^9, 3.49809014941649*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1507: cL, cR = tau,mu (check vs 1505)", "Subsubsection",
 CellChangeTimes->{{3.496594294743198*^9, 3.496594296879119*^9}, {
   3.496594402824727*^9, 3.496594403908146*^9}, 3.4965945104205523`*^9, 
   3.496594588389176*^9, 3.4965947413877172`*^9, 3.4965948564714117`*^9, {
   3.4965950053970423`*^9, 3.49659501509017*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1507a", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.0000715561", ",", "0.00222895", ",", "0.00278702", ",", "0.00218079", 
     ",", "0.000351641"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1507b", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.00112338", ",", "0.0067577", ",", "0.00408936", ",", "0.00228028", ",",
      
     RowBox[{"-", "0.00523939"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1507c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0107702"}], ",", 
     RowBox[{"-", "0.0141159"}], ",", 
     RowBox[{"-", "0.0166831"}], ",", 
     RowBox[{"-", "0.0164702"}], ",", 
     RowBox[{"-", "0.012187"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1507d", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00845894"}], ",", 
     RowBox[{"-", "0.00608441"}], ",", 
     RowBox[{"-", "0.00399178"}], ",", 
     RowBox[{"-", "0.00280744"}], ",", 
     RowBox[{"-", "0.00207793"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1507", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"r1507a", ",", "r1507b", ",", "r1507c", ",", "r1507d"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1507", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1507"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1507", "=", 
   RowBox[{"Interpolation", "[", "Run1507", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1507", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1507", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mtaumu", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1507", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496594302557041*^9, 3.496594367409113*^9}, {
  3.4965944095728407`*^9, 3.4965944726500263`*^9}, {3.496594513050375*^9, 
  3.4965945628644533`*^9}, {3.4965946074526577`*^9, 3.49659465464955*^9}, {
  3.4965946851683197`*^9, 3.496594709693344*^9}, {3.496594763497452*^9, 
  3.496594915002151*^9}, {3.496597066763776*^9, 3.4965970679436827`*^9}, {
  3.496597155274043*^9, 3.49659715853946*^9}, {3.496597332938447*^9, 
  3.496597334066785*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81P8fAHCbkHGHODOElhkp5fWWkYxI0rJX9t6Usu5QuJIUKVGprIQi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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.0000715561}, {0.1, 0.00222895}, {0.2, 0.00278702}, {
     0.5, 0.00218079}, {0.75, 0.000351641}, {1., 0.00112338}, {1.5, 
     0.0067577}, {2., 0.00408936}, {2.5, 0.00228028}, {3., -0.00523939}, {
     3.5, -0.0107702}, {4., -0.0141159}, {4.5, -0.0166831}, {
     5., -0.0164702}, {7., -0.012187}, {9., -0.00845894}, {
     11., -0.00608441}, {14., -0.00399178}, {17., -0.00280744}, {
     20., -0.00207793}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.017051487952554307`, 0.0067568886116802975`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.496594473290841*^9, 3.496594565392531*^9, 3.496594711637485*^9, 
   3.4965948357692432`*^9, 3.4965949153670397`*^9, {3.4965970646604843`*^9, 
   3.496597068726428*^9}, 3.496597158727602*^9, 3.496597334361847*^9, 
   3.496770048773876*^9, 3.4969386524053173`*^9, 3.49696417750239*^9, 
   3.497004161528083*^9, 3.497275530527225*^9, 3.497309459123972*^9, 
   3.497310861465806*^9, 3.497662408415797*^9, 3.498090109017171*^9, 
   3.498090149456472*^9}],

Cell[BoxData[
 RowBox[{"-", "0.11395689961130967`"}]], "Output",
 CellChangeTimes->{
  3.496594473290841*^9, 3.496594565392531*^9, 3.496594711637485*^9, 
   3.4965948357692432`*^9, 3.4965949153670397`*^9, {3.4965970646604843`*^9, 
   3.496597068726428*^9}, 3.496597158727602*^9, 3.496597334361847*^9, 
   3.496770048773876*^9, 3.4969386524053173`*^9, 3.49696417750239*^9, 
   3.497004161528083*^9, 3.497275530527225*^9, 3.497309459123972*^9, 
   3.497310861465806*^9, 3.497662408415797*^9, 3.498090109017171*^9, 
   3.49809014946844*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix of amplitudes", "Section",
 CellChangeTimes->{{3.496597279806493*^9, 3.496597282199465*^9}}],

Cell[TextData[{
 "Note that this excludes several prefactors, including the ",
 StyleBox["f",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " flavor-dependent wavefunction factors."
}], "Text",
 CellChangeTimes->{{3.497004244715403*^9, 3.497004279795629*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"(", GridBox[{
      {"Mee", "Memu", "Metau"},
      {"Memu", "Mmumu", "Mmutau"},
      {"Memu", "Mmutau", "Mtautau"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"M", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.4965972863206787`*^9, 3.496597291995281*^9}, {
  3.496597337975288*^9, 3.496597378275402*^9}, {3.4965975104005404`*^9, 
  3.496597520449586*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.11273569710119061`"}], 
      RowBox[{"-", "0.10010388648214297`"}], 
      RowBox[{"-", "0.10273483151041678`"}]},
     {
      RowBox[{"-", "0.10010388648214297`"}], 
      RowBox[{"-", "0.12337084658273823`"}], 
      RowBox[{"-", "0.11734164624821443`"}]},
     {
      RowBox[{"-", "0.10010388648214297`"}], 
      RowBox[{"-", "0.11734164624821443`"}], 
      RowBox[{"-", "0.11527983193035728`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.49659737378837*^9, 3.496597378726281*^9}, {
   3.496597510889955*^9, 3.496597520690696*^9}, 3.4967700488901777`*^9, 
   3.496938652521068*^9, 3.496964177585496*^9, 3.497004161639369*^9, 
   3.497275530853752*^9, 3.497309459243967*^9, 3.497310861515997*^9, 
   3.4976624084635897`*^9, 3.498090109094829*^9, 3.49809014950653*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diagonalize Yukawa and apply to Amplitude", "Section",
 CellChangeTimes->{{3.496597530921254*^9, 3.4965975343552017`*^9}, 
   3.4965980011528883`*^9, {3.496794594130883*^9, 3.496794596944026*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RandMat", "=", 
   RowBox[{"(", GridBox[{
      {
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}]},
      {
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}]},
      {
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{" ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fMat", "=", 
   RowBox[{"(", GridBox[{
      {"fe", "0", "0"},
      {"0", "f\[Mu]", "0"},
      {"0", "0", "f\[Tau]"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YsMat", "=", 
   RowBox[{"fMat", ".", "RandMat", ".", "fMat"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vecs1", "=", 
   RowBox[{"Eigenvectors", "[", 
    RowBox[{"YsMat", ".", 
     RowBox[{"Transpose", "[", "YsMat", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vecs2", "=", 
    RowBox[{"Eigenvectors", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", "YsMat", "]"}], ".", "YsMat"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"This", " ", "should", " ", "be", " ", "diagonal"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YsDiag", "=", 
   RowBox[{"vecs1", ".", "YsMat", ".", 
    RowBox[{"Transpose", "[", "vecs2", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YsDiag", "//", "Chop"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YsSign", "=", 
   RowBox[{"(", GridBox[{
      {
       FractionBox[
        RowBox[{
         RowBox[{"YsDiag", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"YsDiag", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]], "0", "0"},
      {"0", 
       FractionBox[
        RowBox[{
         RowBox[{"YsDiag", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"YsDiag", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]], "0"},
      {"0", "0", 
       FractionBox[
        RowBox[{
         RowBox[{"YsDiag", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"YsDiag", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "]"}]]}
     }], ")"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Apply", " ", "diagonalization", " ", "to", " ", "the", " ", "amplitude"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mrotated", "=", 
   RowBox[{"vecs1", ".", "fMat", ".", 
    RowBox[{"(", 
     RowBox[{"RandMat", " ", "M"}], ")"}], ".", "fMat", ".", 
    RowBox[{"Transpose", "[", "vecs2", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Mrotated", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Now", " ", "estimate", " ", "\"\<a\>\"", " ", "factor", " ", "by", " ", 
    "pulling", " ", "out", " ", "wavefunctions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Note", " ", "that", " ", "the", " ", "eigenvectors", " ", "are", " ", 
     "re"}], "-", 
    RowBox[{"ordered", " ", "by", " ", "diagonalization"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MrotatedBack", "=", 
    RowBox[{
     RowBox[{"(", GridBox[{
        {
         SuperscriptBox["f\[Tau]", 
          RowBox[{"-", "1"}]], "0", "0"},
        {"0", 
         SuperscriptBox["f\[Mu]", 
          RowBox[{"-", "1"}]], "0"},
        {"0", "0", 
         SuperscriptBox["fe", 
          RowBox[{"-", "1"}]]}
       }], ")"}], ".", "Mrotated", ".", "YsSign", ".", 
     RowBox[{"(", GridBox[{
        {
         SuperscriptBox["f\[Tau]", 
          RowBox[{"-", "1"}]], "0", "0"},
        {"0", 
         SuperscriptBox["f\[Mu]", 
          RowBox[{"-", "1"}]], "0"},
        {"0", "0", 
         SuperscriptBox["fe", 
          RowBox[{"-", "1"}]]}
       }], ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MrotatedBack", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], "/", 
  RowBox[{
   RowBox[{"RandMat", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.496770086259123*^9, 3.49677010035192*^9}, {
   3.4967701482874393`*^9, 3.496770271458664*^9}, {3.496770423956194*^9, 
   3.496770460007801*^9}, {3.496794449766626*^9, 3.496794463602714*^9}, {
   3.496794544358214*^9, 3.4967946095022*^9}, {3.496794719625458*^9, 
   3.4967948230126038`*^9}, {3.496964156326086*^9, 3.496964163898674*^9}, {
   3.4969642057010736`*^9, 3.496964241267696*^9}, 3.497004313707773*^9, {
   3.497004355116207*^9, 3.4970043874948997`*^9}, {3.497275846531683*^9, 
   3.497276002931632*^9}, {3.497276042405435*^9, 3.4972760667618303`*^9}, {
   3.497276704441925*^9, 3.4972767133896837`*^9}, {3.4972767830025797`*^9, 
   3.497276800459293*^9}, {3.497277282329468*^9, 3.49727728386301*^9}, {
   3.497277337962414*^9, 3.497277438489686*^9}, {3.49730944636053*^9, 
   3.497309452517962*^9}, {3.497309795765099*^9, 3.497309799880157*^9}, {
   3.497309879583591*^9, 3.497309975696641*^9}, {3.497310198339801*^9, 
   3.497310225438006*^9}, {3.497311466709722*^9, 3.497311489055747*^9}, {
   3.497311557666934*^9, 3.497311585917014*^9}, {3.4973116165031757`*^9, 
   3.4973116237663517`*^9}, {3.497311696469648*^9, 3.497311770266045*^9}, {
   3.4973118321560307`*^9, 3.497311833881851*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "1.0864288946679626`"}], "1.018991801792807`", 
      "0.9459214882445348`"},
     {
      RowBox[{"-", "0.7738927313702744`"}], 
      RowBox[{"-", "1.322927056561543`"}], 
      RowBox[{"-", "1.7963120473314573`"}]},
     {"1.3295164648782487`", 
      RowBox[{"-", "1.1838648724743859`"}], 
      RowBox[{"-", "0.8440170965270262`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.496794728167778*^9, 3.496794823390046*^9}, {
   3.496796949593718*^9, 3.496796952495633*^9}, 3.496938652779657*^9, {
   3.496964166771842*^9, 3.496964186097361*^9}, {3.496964222796773*^9, 
   3.496964253171973*^9}, 3.4970041617204027`*^9, {3.497004333631435*^9, 
   3.4970043606527853`*^9}, {3.497004400689191*^9, 3.497004407987548*^9}, 
   3.497275531396927*^9, {3.497275840259267*^9, 3.497275841821561*^9}, {
   3.497276067876645*^9, 3.49727608416326*^9}, 3.4972761724582443`*^9, {
   3.497276296820348*^9, 3.497276335416781*^9}, {3.4972766881569653`*^9, 
   3.497276713754723*^9}, {3.4972767522134542`*^9, 3.497276802969935*^9}, 
   3.497277186929242*^9, {3.497277339520812*^9, 3.497277438859055*^9}, {
   3.497309459387941*^9, 3.497309488378771*^9}, {3.497309949911211*^9, 
   3.49730999198656*^9}, 3.497310227212099*^9, 3.49731086156691*^9, 
   3.497311467105562*^9, 3.4973115865109262`*^9, 3.497311624055331*^9, {
   3.497311762469934*^9, 3.497311770512392*^9}, {3.4973118366734753`*^9, 
   3.497311840682032*^9}, 3.497662408499955*^9, 3.498090109134163*^9, 
   3.498090149570383*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.005104502211719762`"}], "0", "0"},
     {"0", "0.00031512451881236624`", "0"},
     {"0", "0", 
      RowBox[{"-", "7.549935096274355`*^-7"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.496794728167778*^9, 3.496794823390046*^9}, {
   3.496796949593718*^9, 3.496796952495633*^9}, 3.496938652779657*^9, {
   3.496964166771842*^9, 3.496964186097361*^9}, {3.496964222796773*^9, 
   3.496964253171973*^9}, 3.4970041617204027`*^9, {3.497004333631435*^9, 
   3.4970043606527853`*^9}, {3.497004400689191*^9, 3.497004407987548*^9}, 
   3.497275531396927*^9, {3.497275840259267*^9, 3.497275841821561*^9}, {
   3.497276067876645*^9, 3.49727608416326*^9}, 3.4972761724582443`*^9, {
   3.497276296820348*^9, 3.497276335416781*^9}, {3.4972766881569653`*^9, 
   3.497276713754723*^9}, {3.4972767522134542`*^9, 3.497276802969935*^9}, 
   3.497277186929242*^9, {3.497277339520812*^9, 3.497277438859055*^9}, {
   3.497309459387941*^9, 3.497309488378771*^9}, {3.497309949911211*^9, 
   3.49730999198656*^9}, 3.497310227212099*^9, 3.49731086156691*^9, 
   3.497311467105562*^9, 3.4973115865109262`*^9, 3.497311624055331*^9, {
   3.497311762469934*^9, 3.497311770512392*^9}, {3.4973118366734753`*^9, 
   3.497311840682032*^9}, 3.497662408499955*^9, 3.498090109134163*^9, 
   3.4980901495876503`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.496794728167778*^9, 3.496794823390046*^9}, {
   3.496796949593718*^9, 3.496796952495633*^9}, 3.496938652779657*^9, {
   3.496964166771842*^9, 3.496964186097361*^9}, {3.496964222796773*^9, 
   3.496964253171973*^9}, 3.4970041617204027`*^9, {3.497004333631435*^9, 
   3.4970043606527853`*^9}, {3.497004400689191*^9, 3.497004407987548*^9}, 
   3.497275531396927*^9, {3.497275840259267*^9, 3.497275841821561*^9}, {
   3.497276067876645*^9, 3.49727608416326*^9}, 3.4972761724582443`*^9, {
   3.497276296820348*^9, 3.497276335416781*^9}, {3.4972766881569653`*^9, 
   3.497276713754723*^9}, {3.4972767522134542`*^9, 3.497276802969935*^9}, 
   3.497277186929242*^9, {3.497277339520812*^9, 3.497277438859055*^9}, {
   3.497309459387941*^9, 3.497309488378771*^9}, {3.497309949911211*^9, 
   3.49730999198656*^9}, 3.497310227212099*^9, 3.49731086156691*^9, 
   3.497311467105562*^9, 3.4973115865109262`*^9, 3.497311624055331*^9, {
   3.497311762469934*^9, 3.497311770512392*^9}, {3.4973118366734753`*^9, 
   3.497311840682032*^9}, 3.497662408499955*^9, 3.498090109134163*^9, 
   3.4980901496435223`*^9}],

Cell[BoxData["5.998810884028772`*^-8"], "Output",
 CellChangeTimes->{{3.496794728167778*^9, 3.496794823390046*^9}, {
   3.496796949593718*^9, 3.496796952495633*^9}, 3.496938652779657*^9, {
   3.496964166771842*^9, 3.496964186097361*^9}, {3.496964222796773*^9, 
   3.496964253171973*^9}, 3.4970041617204027`*^9, {3.497004333631435*^9, 
   3.4970043606527853`*^9}, {3.497004400689191*^9, 3.497004407987548*^9}, 
   3.497275531396927*^9, {3.497275840259267*^9, 3.497275841821561*^9}, {
   3.497276067876645*^9, 3.49727608416326*^9}, 3.4972761724582443`*^9, {
   3.497276296820348*^9, 3.497276335416781*^9}, {3.4972766881569653`*^9, 
   3.497276713754723*^9}, {3.4972767522134542`*^9, 3.497276802969935*^9}, 
   3.497277186929242*^9, {3.497277339520812*^9, 3.497277438859055*^9}, {
   3.497309459387941*^9, 3.497309488378771*^9}, {3.497309949911211*^9, 
   3.49730999198656*^9}, 3.497310227212099*^9, 3.49731086156691*^9, 
   3.497311467105562*^9, 3.4973115865109262`*^9, 3.497311624055331*^9, {
   3.497311762469934*^9, 3.497311770512392*^9}, {3.4973118366734753`*^9, 
   3.497311840682032*^9}, 3.497662408499955*^9, 3.498090109134163*^9, 
   3.4980901496808167`*^9}],

Cell[BoxData["0.002782380011798239`"], "Output",
 CellChangeTimes->{{3.496794728167778*^9, 3.496794823390046*^9}, {
   3.496796949593718*^9, 3.496796952495633*^9}, 3.496938652779657*^9, {
   3.496964166771842*^9, 3.496964186097361*^9}, {3.496964222796773*^9, 
   3.496964253171973*^9}, 3.4970041617204027`*^9, {3.497004333631435*^9, 
   3.4970043606527853`*^9}, {3.497004400689191*^9, 3.497004407987548*^9}, 
   3.497275531396927*^9, {3.497275840259267*^9, 3.497275841821561*^9}, {
   3.497276067876645*^9, 3.49727608416326*^9}, 3.4972761724582443`*^9, {
   3.497276296820348*^9, 3.497276335416781*^9}, {3.4972766881569653`*^9, 
   3.497276713754723*^9}, {3.4972767522134542`*^9, 3.497276802969935*^9}, 
   3.497277186929242*^9, {3.497277339520812*^9, 3.497277438859055*^9}, {
   3.497309459387941*^9, 3.497309488378771*^9}, {3.497309949911211*^9, 
   3.49730999198656*^9}, 3.497310227212099*^9, 3.49731086156691*^9, 
   3.497311467105562*^9, 3.4973115865109262`*^9, 3.497311624055331*^9, {
   3.497311762469934*^9, 3.497311770512392*^9}, {3.4973118366734753`*^9, 
   3.497311840682032*^9}, 3.497662408499955*^9, 3.498090109134163*^9, 
   3.498090149726282*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Useful \"Do\" Loop to generate multiple values quickly\
\>", "Subsection",
 CellChangeTimes->{{3.4967973142668543`*^9, 3.4967973249943523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"numSamples", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"valueList", "=", 
   RowBox[{"Range", "[", "numSamples", "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"Al", "=", ".5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Lower", " ", "anarchic", " ", "limit"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Au", "=", "2"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Upper", " ", "anarchic", " ", "limit"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RandMat", "=", 
     RowBox[{"(", GridBox[{
        {
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}]},
        {
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}]},
        {
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}], 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"Al", ",", "Au"}], "}"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{" ", 
            RowBox[{"RandomInteger", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}]}]]}]}
       }], ")"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"fMat", "=", 
     RowBox[{"(", GridBox[{
        {"fe", "0", "0"},
        {"0", "f\[Mu]", "0"},
        {"0", "0", "f\[Tau]"}
       }], ")"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"YsMat", "=", 
     RowBox[{"fMat", ".", "RandMat", ".", "fMat"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"vecs1", "=", 
     RowBox[{"Eigenvectors", "[", 
      RowBox[{"YsMat", ".", 
       RowBox[{"Transpose", "[", "YsMat", "]"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"vecs2", "=", 
     RowBox[{"Eigenvectors", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", "YsMat", "]"}], ".", "YsMat"}], "]"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"YsDiag", "=", 
     RowBox[{"vecs1", ".", "YsMat", ".", 
      RowBox[{"Transpose", "[", "vecs2", "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"YsDiag", "//", "Chop"}], "//", "MatrixForm"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"YsSign", "=", 
     RowBox[{"(", GridBox[{
        {
         FractionBox[
          RowBox[{
           RowBox[{"YsDiag", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"YsDiag", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]], "0", "0"},
        {"0", 
         FractionBox[
          RowBox[{
           RowBox[{"YsDiag", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"YsDiag", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]], "0"},
        {"0", "0", 
         FractionBox[
          RowBox[{
           RowBox[{"YsDiag", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}], 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"YsDiag", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}]]}
       }], ")"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Apply", " ", "diagonalization", " ", "to", " ", "the", " ", 
      "amplitude"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Mrotated", "=", 
     RowBox[{"vecs1", ".", "fMat", ".", 
      RowBox[{"(", 
       RowBox[{"RandMat", " ", "M"}], ")"}], ".", "fMat", ".", 
      RowBox[{"Transpose", "[", "vecs2", "]"}]}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Now", " ", "estimate", " ", "\"\<a\>\"", " ", "factor", " ", "by", " ", 
      "pulling", " ", "out", " ", "wavefunctions"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "Note", " ", "that", " ", "the", " ", "eigenvectors", " ", "are", " ", 
       "re"}], "-", 
      RowBox[{"ordered", " ", "by", " ", "diagonalization"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"MrotatedBack", "=", 
     RowBox[{
      RowBox[{"(", GridBox[{
         {
          SuperscriptBox["f\[Tau]", 
           RowBox[{"-", "1"}]], "0", "0"},
         {"0", 
          SuperscriptBox["f\[Mu]", 
           RowBox[{"-", "1"}]], "0"},
         {"0", "0", 
          SuperscriptBox["fe", 
           RowBox[{"-", "1"}]]}
        }], ")"}], ".", "Mrotated", ".", "YsSign", ".", 
      RowBox[{"(", GridBox[{
         {
          SuperscriptBox["f\[Tau]", 
           RowBox[{"-", "1"}]], "0", "0"},
         {"0", 
          SuperscriptBox["f\[Mu]", 
           RowBox[{"-", "1"}]], "0"},
         {"0", "0", 
          SuperscriptBox["fe", 
           RowBox[{"-", "1"}]]}
        }], ")"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"MrotatedBack", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/", 
        RowBox[{
         RowBox[{"RandMat", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"valueList", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"MrotatedBack", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "/", 
      RowBox[{
       RowBox[{"RandMat", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "numSamples"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Histogram", "[", 
  RowBox[{"valueList", ",", 
   RowBox[{"HistogramRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", ".2"}], ",", ".2"}], "}"}]}], ",", 
   RowBox[{"HistogramCategories", "\[Rule]", "160"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.496797217544939*^9, 3.4967972889635763`*^9}, {
  3.49679734584798*^9, 3.496797346381239*^9}, {3.49679740683038*^9, 
  3.496797422741744*^9}, {3.496964299012312*^9, 3.496964301040215*^9}, {
  3.497276317249049*^9, 3.497276347581218*^9}, {3.4972763776928368`*^9, 
  3.497276489303771*^9}, {3.49727666148746*^9, 3.4972766665585403`*^9}, {
  3.497309435885474*^9, 3.497309438282331*^9}, {3.497310178670527*^9, 
  3.49731019479762*^9}, {3.4973102406991787`*^9, 3.497310354245552*^9}, {
  3.497310400169216*^9, 3.497310409768968*^9}, {3.4973108974444313`*^9, 
  3.497310953142329*^9}, {3.497311099550519*^9, 3.4973111074855223`*^9}, {
  3.497311219900588*^9, 3.497311250075857*^9}, {3.497311858052554*^9, 
  3.497311875112328*^9}, {3.4976624276679068`*^9, 3.497662459926426*^9}, {
  3.497662520842811*^9, 3.497662534401154*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.2, 0}, {-0.1975, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.1975, 0}, {-0.195, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.195, 0}, {-0.1925, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.1925, 0}, {-0.19, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.19, 0}, {-0.1875, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.1875, 0}, {-0.185, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.185, 0}, {-0.1825, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.1825, 0}, {-0.18, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.18, 0}, {-0.1775, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.1775, 0}, {-0.175, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], RectangleBox[{-0.175, 0}, {-0.1725, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.1725, 0}, {-0.16999999999999998`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.16999999999999998`, 0}, {-0.16749999999999998`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.16749999999999998`, 0}, {-0.16499999999999998`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.16499999999999998`, 0}, {-0.16249999999999998`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.16249999999999998`, 0}, {-0.15999999999999998`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.15999999999999998`, 0}, {-0.15749999999999997`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.15749999999999997`, 0}, {-0.15499999999999997`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.15499999999999997`, 0}, {-0.15249999999999997`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.15249999999999997`, 0}, {-0.14999999999999997`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.14999999999999997`, 0}, {-0.14749999999999996`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.14749999999999996`, 0}, {-0.14499999999999996`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.14499999999999996`, 0}, {-0.14249999999999996`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.14249999999999996`, 0}, {-0.13999999999999996`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.13999999999999996`, 0}, {-0.13749999999999996`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.13749999999999996`, 0}, {-0.13499999999999995`, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.13499999999999995`, 0}, {-0.13249999999999995`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.13249999999999995`, 0}, {-0.12999999999999995`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.12999999999999995`, 0}, {-0.12749999999999995`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.12749999999999995`, 0}, {-0.12499999999999994`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.12499999999999994`, 0}, {-0.12249999999999994`, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.12249999999999994`, 0}, {-0.11999999999999994`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.11999999999999994`, 0}, {-0.11749999999999994`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.11749999999999994`, 0}, {-0.11499999999999994`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.11499999999999994`, 0}, {-0.11249999999999993`, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.11249999999999993`, 0}, {-0.10999999999999993`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.10999999999999993`, 0}, {-0.10749999999999993`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.10749999999999993`, 0}, {-0.10499999999999993`, 5}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.10499999999999993`, 0}, {-0.10249999999999992`, 7}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.10249999999999992`, 0}, {-0.09999999999999992, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.09999999999999992, 0}, {-0.09749999999999992, 4}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.09749999999999992, 0}, {-0.09499999999999992, 4}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.09499999999999992, 0}, {-0.09249999999999992, 9}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.09249999999999992, 0}, {-0.08999999999999991, 5}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.08999999999999991, 0}, {-0.08749999999999991, 6}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.08749999999999991, 0}, {-0.08499999999999991, 5}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.08499999999999991, 0}, {-0.0824999999999999, 5}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0824999999999999, 0}, {-0.0799999999999999, 10}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0799999999999999, 0}, {-0.0774999999999999, 10}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0774999999999999, 0}, {-0.0749999999999999, 11}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0749999999999999, 0}, {-0.0724999999999999, 11}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0724999999999999, 0}, {-0.0699999999999999, 19}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0699999999999999, 0}, {-0.0674999999999999, 16}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0674999999999999, 0}, {-0.06499999999999989, 18}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.06499999999999989, 0}, {-0.06249999999999989, 21}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.06249999999999989, 0}, {-0.05999999999999989, 30}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.05999999999999989, 0}, {-0.057499999999999885`, 37}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.057499999999999885`, 0}, {-0.05499999999999988, 48}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.05499999999999988, 0}, {-0.05249999999999988, 69}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.05249999999999988, 0}, {-0.04999999999999988, 56}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.04999999999999988, 0}, {-0.047499999999999876`, 90}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.047499999999999876`, 0}, {-0.04499999999999987, 84}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.04499999999999987, 0}, {-0.04249999999999987, 122}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.04249999999999987, 0}, {-0.03999999999999987, 146}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.03999999999999987, 0}, {-0.03749999999999987, 190}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.03749999999999987, 0}, {-0.034999999999999865`, 218}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.034999999999999865`, 0}, {-0.03249999999999986, 256}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.03249999999999986, 0}, {-0.02999999999999986, 256}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.02999999999999986, 0}, {-0.027499999999999858`, 246}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.027499999999999858`, 0}, \
{-0.024999999999999856`, 236}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.024999999999999856`, 0}, \
{-0.022499999999999853`, 141}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.022499999999999853`, 0}, {-0.01999999999999985, 125}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.01999999999999985, 0}, {-0.01749999999999985, 182}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.01749999999999985, 0}, {-0.014999999999999847`, 247}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.014999999999999847`, 0}, \
{-0.012499999999999845`, 286}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.012499999999999845`, 0}, {-0.009999999999999842, 286}]}, \

   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.009999999999999842, 0}, {-0.00749999999999984, 315}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.00749999999999984, 0}, {-0.004999999999999838, 364}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.004999999999999838, 0}, \
{-0.0024999999999998357`, 414}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{-0.0024999999999998357`, 0}, \
{1.6653345369377348`*^-16, 380}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{1.6653345369377348`*^-16, 0}, \
{0.0025000000000001688`, 414}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.0025000000000001688`, 0}, {0.005000000000000171, 391}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.005000000000000171, 0}, {0.007500000000000173, 355}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.007500000000000173, 0}, {0.010000000000000175`, 329}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.010000000000000175`, 0}, {0.012500000000000178`, 292}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.012500000000000178`, 0}, {0.01500000000000018, 287}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.01500000000000018, 0}, {0.017500000000000182`, 277}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.017500000000000182`, 0}, {0.020000000000000184`, 194}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.020000000000000184`, 0}, {0.022500000000000187`, 129}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.022500000000000187`, 0}, {0.02500000000000019, 150}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.02500000000000019, 0}, {0.02750000000000019, 238}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.02750000000000019, 0}, {0.030000000000000193`, 239}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.030000000000000193`, 0}, {0.032500000000000195`, 259}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.032500000000000195`, 0}, {0.0350000000000002, 223}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.0350000000000002, 0}, {0.0375000000000002, 206}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.0375000000000002, 0}, {0.0400000000000002, 174}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.0400000000000002, 0}, {0.042500000000000204`, 153}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.042500000000000204`, 0}, {0.045000000000000207`, 96}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.045000000000000207`, 0}, {0.04750000000000021, 82}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.04750000000000021, 0}, {0.05000000000000021, 77}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.05000000000000021, 0}, {0.05250000000000021, 64}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.05250000000000021, 0}, {0.055000000000000215`, 66}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.055000000000000215`, 0}, {0.05750000000000022, 39}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.05750000000000022, 0}, {0.06000000000000022, 46}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.06000000000000022, 0}, {0.06250000000000022, 30}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.06250000000000022, 0}, {0.06500000000000022, 31}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.06500000000000022, 0}, {0.06750000000000023, 17}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.06750000000000023, 0}, {0.07000000000000023, 21}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.07000000000000023, 0}, {0.07250000000000023, 18}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.07250000000000023, 0}, {0.07500000000000023, 15}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.07500000000000023, 0}, {0.07750000000000024, 11}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.07750000000000024, 0}, {0.08000000000000024, 4}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.08000000000000024, 0}, {0.08250000000000024, 7}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.08250000000000024, 0}, {0.08500000000000024, 12}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.08500000000000024, 0}, {0.08750000000000024, 6}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.08750000000000024, 0}, {0.09000000000000025, 7}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.09000000000000025, 0}, {0.09250000000000025, 6}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.09250000000000025, 0}, {0.09500000000000025, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.09500000000000025, 0}, {0.09750000000000025, 9}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.09750000000000025, 0}, {0.10000000000000026`, 4}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.10000000000000026`, 0}, {0.10250000000000026`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.10250000000000026`, 0}, {0.10500000000000026`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.10500000000000026`, 0}, {0.10750000000000026`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.10750000000000026`, 0}, {0.11000000000000026`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.11000000000000026`, 0}, {0.11250000000000027`, 3}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.11250000000000027`, 0}, {0.11500000000000027`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.11500000000000027`, 0}, {0.11750000000000027`, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.11750000000000027`, 0}, {0.12000000000000027`, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.12000000000000027`, 0}, {0.12250000000000028`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.12250000000000028`, 0}, {0.12500000000000028`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.12500000000000028`, 0}, {0.12750000000000028`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.12750000000000028`, 0}, {0.13000000000000028`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.13000000000000028`, 0}, {0.13250000000000028`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.13250000000000028`, 0}, {0.1350000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1350000000000003, 0}, {0.1375000000000003, 2}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1375000000000003, 0}, {0.1400000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1400000000000003, 0}, {0.1425000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1425000000000003, 0}, {0.1450000000000003, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1450000000000003, 0}, {0.1475000000000003, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1475000000000003, 0}, {0.1500000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1500000000000003, 0}, {0.1525000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1525000000000003, 0}, {0.1550000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1550000000000003, 0}, {0.1575000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1575000000000003, 0}, {0.1600000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1600000000000003, 0}, {0.1625000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1625000000000003, 0}, {0.1650000000000003, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.1650000000000003, 0}, {0.16750000000000032`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.16750000000000032`, 0}, {0.17000000000000032`, 1}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.17000000000000032`, 0}, {0.17250000000000032`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.17250000000000032`, 0}, {0.17500000000000032`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.17500000000000032`, 0}, {0.17750000000000032`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.17750000000000032`, 0}, {0.18000000000000033`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.18000000000000033`, 0}, {0.18250000000000033`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.18250000000000033`, 0}, {0.18500000000000033`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.18500000000000033`, 0}, {0.18750000000000033`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.18750000000000033`, 0}, {0.19000000000000034`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.19000000000000034`, 0}, {0.19250000000000034`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.19250000000000034`, 0}, {0.19500000000000034`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.19500000000000034`, 0}, {0.19750000000000034`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.19750000000000034`, 0}, {0.20000000000000034`, 0}]}, 
   {RGBColor[0.7771114671549554, 0.7981689173723965, 0.92304875257496], 
    EdgeForm[GrayLevel[0]], 
    RectangleBox[{0.20000000000000034`, 0}, {0.20250000000000035`, 0}]}},
  AlignmentPoint->Center,
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->None,
  AxesOrigin->{-0.2, 0},
  AxesStyle->{},
  Background->None,
  BaseStyle->{},
  BaselinePosition->Automatic,
  ColorOutput->Automatic,
  ContentSelectable->Automatic,
  DisplayFunction:>$DisplayFunction,
  Epilog->{},
  FormatType:>TraditionalForm,
  Frame->False,
  FrameLabel->None,
  FrameStyle->{},
  FrameTicks->Automatic,
  FrameTicksStyle->{},
  GridLines->None,
  GridLinesStyle->{},
  ImageMargins->0.,
  ImagePadding->All,
  ImageSize->Automatic,
  LabelStyle->{},
  Method->Automatic,
  PlotLabel->None,
  PlotRange->{{-0.2, 0.20250000000000035`}, All},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  PlotRegion->Automatic,
  PreserveImageOptions->Automatic,
  Prolog->{},
  RotateLabel->True,
  Ticks->{{{-0.2, 
      FormBox[
       RowBox[{"-", "0.2`"}], TraditionalForm]}, {-0.1, 
      FormBox[
       RowBox[{"-", "0.1`"}], TraditionalForm]}, {0., 
      FormBox["0", TraditionalForm]}, {0.1, 
      FormBox["0.1`", TraditionalForm]}, {0.2, 
      FormBox["0.2`", TraditionalForm]}}, Automatic},
  TicksStyle->{}]], "Output",
 CellChangeTimes->{{3.497310329237911*^9, 3.497310354743518*^9}, {
   3.4973103936335363`*^9, 3.4973104103659687`*^9}, {3.497310851505724*^9, 
   3.497310861916275*^9}, {3.4973108981917067`*^9, 3.497310955441181*^9}, {
   3.497311102024304*^9, 3.497311110191216*^9}, 3.497311181836673*^9, {
   3.497311222857979*^9, 3.497311252637147*^9}, 3.4973118779636097`*^9, 
   3.497662411244535*^9, {3.4976625125819483`*^9, 3.497662537844352*^9}, 
   3.4980901115202*^9, 3.4980901519891*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{832, 648},
WindowMargins->{{Automatic, 142}, {Automatic, 44}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (March 13, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 204, 3, 76, "Title"],
Cell[797, 28, 1535, 31, 206, "Text"],
Cell[2335, 61, 142, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[2502, 67, 99, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[2626, 72, 268, 8, 36, "Subsection"],
Cell[2897, 82, 243, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[3165, 91, 3912, 112, 518, "Input"],
Cell[7080, 205, 499, 9, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7628, 220, 102, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[7755, 225, 1096, 31, 103, "Input"],
Cell[8854, 258, 641, 12, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9532, 275, 161, 2, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[9718, 281, 2349, 69, 178, "Input"],
Cell[12070, 352, 12431, 211, 222, "Output"],
Cell[24504, 565, 468, 7, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25021, 578, 165, 2, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[25211, 584, 2277, 66, 178, "Input"],
Cell[27491, 652, 8487, 145, 225, "Output"],
Cell[35981, 799, 440, 7, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36470, 812, 213, 3, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[36708, 819, 2290, 66, 178, "Input"],
Cell[39001, 887, 8198, 138, 222, "Output"],
Cell[47202, 1027, 386, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47637, 1039, 239, 3, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[47901, 1046, 2369, 68, 178, "Input"],
Cell[50273, 1116, 11892, 200, 222, "Output"],
Cell[62168, 1318, 407, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62624, 1330, 264, 3, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[62913, 1337, 2569, 74, 184, "Input"],
Cell[65485, 1413, 11359, 192, 225, "Output"],
Cell[76847, 1607, 429, 7, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77325, 1620, 291, 4, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[77641, 1628, 2733, 79, 184, "Input"],
Cell[80377, 1709, 603, 11, 33, "Output"],
Cell[80983, 1722, 11251, 189, 222, "Output"],
Cell[92237, 1913, 476, 7, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[92762, 1926, 331, 4, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[93118, 1934, 2533, 71, 178, "Input"],
Cell[95654, 2007, 13115, 221, 222, "Output"],
Cell[108772, 2230, 537, 9, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[109382, 2247, 105, 1, 67, "Section"],
Cell[109490, 2250, 260, 7, 26, "Text"],
Cell[CellGroupData[{
Cell[109775, 2261, 438, 11, 80, "Input"],
Cell[110216, 2274, 1334, 32, 73, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[111599, 2312, 202, 2, 67, "Section"],
Cell[CellGroupData[{
Cell[111826, 2318, 9029, 260, 619, "Input"],
Cell[120858, 2580, 2027, 41, 73, "Output"],
Cell[122888, 2623, 1837, 36, 76, "Output"],
Cell[124728, 2661, 1423, 26, 27, "Output"],
Cell[126154, 2689, 1164, 16, 30, "Output"],
Cell[127321, 2707, 1161, 16, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128519, 2728, 154, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[128698, 2735, 10255, 282, 746, "Input"],
Cell[138956, 3019, 29801, 532, 241, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
