(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    114483,       2461]
NotebookOptionsPosition[    111079,       2350]
NotebookOutlinePosition[    111471,       2367]
CellTagsIndexPosition[    111428,       2364]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Run 17: 3x MI Z loop", "Title",
 CellChangeTimes->{{3.497313844362248*^9, 3.4973138528743267`*^9}, 
   3.498605736322509*^9, {3.498607866598196*^9, 3.498607867945253*^9}}],

Cell["\<\
Flip Tanedo
28 October 2010
Redone: 12 November 2010 using revised data points (Y*=2)

3xMI Z loop diagram analysis. Note that these get extra suppression factors \
relative to other diagrams. The terms calculated here are just *half* of the \
terms contributing to the amplitude. The other half come from the 1xMI \
amplitude times the appropriate prefactors. See my hand-written notes. \
\>", "Text",
 CellChangeTimes->{{3.497313854299902*^9, 3.497313865409978*^9}, {
  3.497314455289472*^9, 3.497314472191039*^9}, {3.498603398626893*^9, 
  3.498603468285606*^9}}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4986038668174753`*^9, 3.498603873009096*^9}}],

Cell[CellGroupData[{

Cell["Set up the points", "Section",
 CellChangeTimes->{{3.4963319218472548`*^9, 3.496331923993202*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"yvals1", "=", 
   RowBox[{"{", 
    RowBox[{".01", ",", ".1", ",", ".2", ",", ".5", ",", ".75"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yvals2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1.5", ",", "2", ",", "2.5", ",", "3"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yvals3", "=", 
   RowBox[{"{", 
    RowBox[{"3.5", ",", "4", ",", "4.5", ",", "5", ",", "7"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yvals4", "=", 
   RowBox[{"{", 
    RowBox[{"9", ",", "11", ",", "14", ",", "17", ",", "20"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"yvals", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"yvals1", ",", "yvals2", ",", "yvals3", ",", "yvals4"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.4963319247921762`*^9, 3.4963319667328663`*^9}, {
  3.496332068343708*^9, 3.496332101158099*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.01`", ",", "0.1`", ",", "0.2`", ",", "0.5`", ",", "0.75`", ",", "1", ",",
    "1.5`", ",", "2", ",", "2.5`", ",", "3", ",", "3.5`", ",", "4", ",", 
   "4.5`", ",", "5", ",", "7", ",", "9", ",", "11", ",", "14", ",", "17", ",",
    "20"}], "}"}]], "Output",
 CellChangeTimes->{{3.496332079852742*^9, 3.4963321014874496`*^9}, 
   3.496501184919468*^9, {3.498603861347838*^9, 3.498603875054469*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"yvalsshort", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.1`", ",", "0.2`", ",", "0.5`", ",", "0.75`", ",", "1", ",", "1.5`", 
     ",", "2", ",", "2.5`", ",", "3", ",", "3.5`", ",", "4", ",", "4.5`", ",",
      "5", ",", "7", ",", "9", ",", "11", ",", "14", ",", "17", ",", "20"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.498604457155109*^9, 3.498604465289604*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolations", "Section",
 CellChangeTimes->{{3.497313886600559*^9, 3.4973138877705936`*^9}}],

Cell[CellGroupData[{

Cell["Run 1701: cL=.667, -cR=.667, cLi=.667, -cRi=.667", "Subsection",
 CellChangeTimes->{{3.497313889939773*^9, 3.497313893298924*^9}, {
  3.497314493802484*^9, 3.497314497168442*^9}, {3.498603616714102*^9, 
  3.4986036383587093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tempA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]]}], ",", 
     RowBox[{"-", "0.0309532"}], ",", 
     RowBox[{"-", "0.0279277"}], ",", 
     RowBox[{"-", "0.0187654"}], ",", 
     RowBox[{"-", "0.0149042"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00961638"}], ",", 
     RowBox[{"-", "0.00698553"}], ",", 
     RowBox[{"-", "0.00722254"}], ",", 
     RowBox[{"-", "0.00789598"}], ",", 
     RowBox[{"-", "0.00765113"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00675284"}], ",", 
     RowBox[{"-", "0.00566786"}], ",", 
     RowBox[{"-", "0.00463532"}], ",", 
     RowBox[{"-", "0.00375828"}], ",", 
     RowBox[{"-", "0.00170315"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000881284"}], ",", 
     RowBox[{"-", "0.000509589"}], ",", 
     RowBox[{"-", "0.000259545"}], ",", 
     RowBox[{"-", "0.000149382"}], ",", 
     RowBox[{"-", "0.0000936294"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1701", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1701", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1701"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1701", "=", 
  RowBox[{"Interpolation", "[", "Run1701", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1701", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1701", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Meeee", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1701", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", "0.0309532`"}], ",", 
   RowBox[{"-", "0.0279277`"}], ",", 
   RowBox[{"-", "0.0187654`"}], ",", 
   RowBox[{"-", "0.0149042`"}], ",", 
   RowBox[{"-", "0.00961638`"}], ",", 
   RowBox[{"-", "0.00698553`"}], ",", 
   RowBox[{"-", "0.00722254`"}], ",", 
   RowBox[{"-", "0.00789598`"}], ",", 
   RowBox[{"-", "0.00765113`"}], ",", 
   RowBox[{"-", "0.00675284`"}], ",", 
   RowBox[{"-", "0.00566786`"}], ",", 
   RowBox[{"-", "0.00463532`"}], ",", 
   RowBox[{"-", "0.00375828`"}], ",", 
   RowBox[{"-", "0.00170315`"}], ",", 
   RowBox[{"-", "0.000881284`"}], ",", 
   RowBox[{"-", "0.000509589`"}], ",", 
   RowBox[{"-", "0.000259545`"}], ",", 
   RowBox[{"-", "0.000149382`"}], ",", 
   RowBox[{"-", "0.0000936294`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
  3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
  3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.01`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
   "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
  3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
  3.498603876766838*^9}, {3.498603954127486*^9, 3.49860398333187*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, -2.4064205205592826`*^-7}, {
      0.016131291231986936`, -0.0035012625215503773`}, {
      0.022262174504790202`, -0.006775223810723496}, {
      0.028393057777593468`, -0.009827679623035799}, {
      0.03452394105039673, -0.012664185071951665`}, {
      0.040654824323199994`, -0.015290295270935481`}, {
      0.042587159461411284`, -0.01605343249157934}}], 
     LineBox[{{0.2638934448384051, -0.01605343249157934}, {
      0.26749750541692074`, -0.015316693882102207`}, {
      0.2797592719625273, -0.012817807614628644`}, {
      0.3042828050537404, -0.008006187451115893}, {
      0.31041368832654365`, -0.0068744689828287645`}, {
      0.3165445715993469, -0.00578233537050683}, {
      0.32267545487215016`, -0.004735341727614469}, {
      0.3288063381449534, -0.003739043167616061}, {
      0.33493722141775667`, -0.002798994803975996}, {
      0.3410681046905599, -0.0019207517501586523`}, {
      0.34719898796336324`, -0.0011098691196284073`}, {
      0.3533298712361665, -0.00037190202584966303`}, {0.35946075450896975`, 
      0.0002875944177132342}, {0.36559163778177306`, 0.0008630650975958581}, {
      0.3717225210545763, 0.0013489549003338243`}, {0.37785340432737957`, 
      0.0017397087124628}, {0.3839842876001828, 0.002029771420518342}, {
      0.3901151708729861, 0.002213587911036128}, {0.39624605414578934`, 
      0.0022856030705517075`}, {0.4023769374185926, 0.002240261785600769}, {
      0.40902351742983833`, 0.0020520763217580437`}, {0.415670097441084, 
      0.0017123542279104224`}, {0.4223166774523297, 0.0012140173745830603`}, {
      0.42896325746357544`, 0.0005499876323010397}, {
      0.4356098374748212, -0.00028681312841051174`}, {
      0.44225641748606687`, -0.00130346303702647}, {
      0.44890299749731255`, -0.00250704022302169}, {
      0.4555495775085583, -0.003904622815871091}, {
      0.46219615751980403`, -0.005503288945049537}, {
      0.4688427375310497, -0.0073101167400319005`}, {
      0.4754893175422954, -0.009332184330293052}, {
      0.48213589755354114`, -0.011576569845307909`}, {
      0.4887824775647869, -0.014050351414551328`}, {
      0.49369479575948233`, -0.01605343249157934}}], LineBox[CompressedData["
1:eJwV1nc81d8fB3Cua0Yp65K9SbikInWOmSTZI2XvJhFx3XsJkTIiKSINkcqo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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.}, {0.1, -0.0309532}, {0.2, -0.0279277}, {
     0.5, -0.0187654}, {0.75, -0.0149042}, {1., -0.00961638}, {
     1.5, -0.00698553}, {2., -0.00722254}, {2.5, -0.00789598}, {
     3., -0.00765113}, {3.5, -0.00675284}, {4., -0.00566786}, {
     4.5, -0.00463532}, {5., -0.00375828}, {7., -0.00170315}, {
     9., -0.000881284}, {11., -0.000509589}, {14., -0.000259545}, {
     17., -0.000149382}, {20., -0.0000936294}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.01605343249157934, 0.0022856030705517075`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
  3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
  3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983368167*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.05191533366546645`"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
  3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
  3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983421517*^9}}]
}, Open  ]],

Cell[TextData[{
 "Here I did the interpolation only on points with appreciable accuracy. I \
ignore the first data point since this gives strange features to the \
interpolation. The cost is that the value of the graph near zero has to be an \
",
 StyleBox["ex",
  FontSlant->"Italic"],
 "trapolation, but this seems to not be a problem. "
}], "Text",
 CellChangeTimes->{{3.498604559495553*^9, 3.498604623077466*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tempA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0309532"}], ",", 
     RowBox[{"-", "0.0279277"}], ",", 
     RowBox[{"-", "0.0187654"}], ",", 
     RowBox[{"-", "0.0149042"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00961638"}], ",", 
     RowBox[{"-", "0.00698553"}], ",", 
     RowBox[{"-", "0.00722254"}], ",", 
     RowBox[{"-", "0.00789598"}], ",", 
     RowBox[{"-", "0.00765113"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00675284"}], ",", 
     RowBox[{"-", "0.00566786"}], ",", 
     RowBox[{"-", "0.00463532"}], ",", 
     RowBox[{"-", "0.00375828"}], ",", 
     RowBox[{"-", "0.00170315"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000881284"}], ",", 
     RowBox[{"-", "0.000509589"}], ",", 
     RowBox[{"-", "0.000259545"}], ",", 
     RowBox[{"-", "0.000149382"}], ",", 
     RowBox[{"-", "0.0000936294"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1701s", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1701s", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvalsshort", ",", "r1701s"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1701s", "=", 
  RowBox[{"Interpolation", "[", "Run1701s", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1701s", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1701s", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Meeee", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1701s", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}, {3.4986044799571447`*^9, 
  3.498604498700246*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0309532`"}], ",", 
   RowBox[{"-", "0.0279277`"}], ",", 
   RowBox[{"-", "0.0187654`"}], ",", 
   RowBox[{"-", "0.0149042`"}], ",", 
   RowBox[{"-", "0.00961638`"}], ",", 
   RowBox[{"-", "0.00698553`"}], ",", 
   RowBox[{"-", "0.00722254`"}], ",", 
   RowBox[{"-", "0.00789598`"}], ",", 
   RowBox[{"-", "0.00765113`"}], ",", 
   RowBox[{"-", "0.00675284`"}], ",", 
   RowBox[{"-", "0.00566786`"}], ",", 
   RowBox[{"-", "0.00463532`"}], ",", 
   RowBox[{"-", "0.00375828`"}], ",", 
   RowBox[{"-", "0.00170315`"}], ",", 
   RowBox[{"-", "0.000881284`"}], ",", 
   RowBox[{"-", "0.000509589`"}], ",", 
   RowBox[{"-", "0.000259545`"}], ",", 
   RowBox[{"-", "0.000149382`"}], ",", 
   RowBox[{"-", "0.0000936294`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4986045029169416`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.1`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.498604502947732*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterpolatingFunction", "::", "\<\"dmval\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\({0.010408367142857143`}\\) lies outside \
the range of data in the interpolating function. Extrapolation will be used. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.498604502985154*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc81d8fB3DjmlHKumRvEi6pSJ1jJkl2Stlbiyhx3XsJkbJJEWmIVEZl
lLwblFHJbHxLZkbKyLzW7/P76/N4Ps7nvD7n/T7n83l8ZD1O2XqzsbCwRLCy
sPz/Ks+v8GHszQCSf2KQcWt3KgzoTf8WGhpAG7oT3aa3psJL+cDWi5sHUafx
6GdnoVQ4P38060T8IDIREHC41pcC43lYQc9jCA1l5j6TjEyBpvgargfZQ0jX
xiFfyCsFCoO1f0u1DqFwSXvg3p8CrmYKFSSDX4hxdGd1GzkF2v9w4U/Cw8hi
lwMt0ScZSj8z5I0th9EdQTPXdTrJcPnVImdl9DA6+F2oQ3UtCfxKgsdUaoaR
SOv+Y/81J4Fp5u8PORPDqEExNEooKwnk6F7l65VGkFRem98p+yRY9fuREXV0
BOUZlE7N8iVBtUGrs2/TCGJ8CFrKoV6BTCVz9G1tBD25xTbcrHMFggVeyR3Y
PopuiUY8zhq7DFsGK0a1b48i68LwevlDlyEvMevcKnUMudeJ5/5WT4RPYlqF
XaVjaCa1gtL56xKwFTV1PugfQwpl6Q9zbl4C7/plirP5b/Tp82pQr+AlUF/x
GK8SHEdJCkL9k4vx8PykpnvQ/T/ovK4wqaQpDsaXG5PNf/xB93n3kc7ExIFU
okedtMBfZOXEtKGhOIi+l7n5Y+hf5O93a+JcZSw80dW0uFv0F+WW0d8HB8fC
rzeNYdT//qIa6j2BZo1YsOhd6lIznECqD26PFBbFAPVkJoktZALtyHTh0fOJ
gYfLGjpfCyfQPX5KCVaIgZ5Lje5lXyeQg1OSUH3/BYjnozQac04iM6pArVXh
BSjoiHQtlZ5Ev1xVX5wPuwDPrjfPietNon/rVRpy91+AcRUvxenASXTR+rj3
q5lo4Jgsqz0WO4nu3qbuqmuOBqmqFbumvEnkZsydUVwQDdamV6Nvtk2i76NK
5ka20fDEvfmn1Y4ptMM5W1KvLgo+qIiee2Y9hS7mXPPzzYmCXxOe65UCplC7
muHWoPNRQKatGKzkTqH4KnI+/84oiLiudb2EbRq92cgSpwwMyHCPpIhKTKPt
thZrf28x4IFKc2O07jRiH/QepV1kQE+l5/xhv2nUTS1M/GvLgPnIsqSGqGkU
YpIV1aTHAAHTFUVKzjTK7Rn39JRlgFFHlj33x2nkKdrYnjFEB+frA7/PDE+j
oLq8DMUaOoS4a134yfIP/eE7qSSbRIfCiabySp1/KPWWbLmpAR14+VbWe1/7
h0Re8ShCEQ3urCOvWVf8Q0sZqt1vL9JgzzqdCYOWf2jYhwM4/WgQxOvfKrTy
D5lQ9ppLqtOAlzcGWERm0BT6Mjm2gZjPk186rjGDhM9H9PXMRMIX7q7kercZ
tOeqVYny60gI5p6kl52fQdS04stn7kcCH/e607lpM+je4PG3HemRgLkMrUPq
Z9DOZ9F24B8J3ziPYrcfM+izHUupoWMkhHCe07Kcm0Hdpw3OvDWOhHscDwUU
VGZRoLuZWYMsMZ+jkUXAcBbp7UfHtm8i5pMGJpcOz6L/Bi3/XGUn5pNWe4eD
Z9GJmpjwoVkqrCeJtXUkziJ+++V48VEqFLFvewV3ZtEX1JSr/YMKRuwHy0te
zKJRLlZ91XYqfGcLKLjaPYtcd9QMLr6jwlm22NQLE7PI8TCX7M06Kgiw3Yw6
xT2HxhZYzohWUuE+6/MgZ9k5pFfw3MX5ERVMWLvd9+rPIbcfln6+96jwg2XK
RsduDkXsbBbcUUDksfAZSR+fQ0W79w015BB5LMra62LnEHvYT7cNV4m8NUO5
+RvEePAt3g3pRN7a0U0DlXPoafU9n5fJVOhZPcfW2jqH9naRFqWuUCFsNW36
2QiRb9dqqpRIhU2rD/sLWefRiTqJtrYEKpSsNLanic8j/QI2aUnCJisDr2k6
82gtLusxO+Ge5dWKAMt59I35Z1MU4bBlsduO3vPo10WpVymXiLzlbelGtHlk
WLPbSOMyFR4sHbygcXUecYm7izskUcFsKeCMeNk8ctTN+8CSSoVeZqwnZ9M8
ssji7VXPoEI486bddN88Yml83tVJ1CfEfG7cw5xHmQ7vtGeI+h8tdus0Cy6g
ojkWAyZxv/nilHyl+gIyzK4rCSbq6VvgE7pluoC4ajxWj0QTeQvKpCSXBeS6
8oWz4jyRt2A0c/7cAqrg4c8+G0TkzR8b9E5ZQN7RYzH3/Im8+bBOm+IF1Lfu
2E1jDyr0z6XX7369gC5bWL/Y50wF6tyjJ6r/LaCP/aWPqu2pUDY7mMHKv4hK
yz2OvDengsXsWswfxUUkSbny7KQxFQZnxEO/7llEdTnt+qF7qECb0fVuOLSI
FjKlHvXoUUF0xtqh/PQi0qk/OlysS+T9CzS9kbCIuprDarooRN6/ON2EW4vI
1Mpl3k2DyJsuUAx9voh+Ty+csdhC5E3XCrt3LqKtx7axpaoQ/Z2XbfCfWETx
PtdtSEpU4F+OCwnmZaKCmTXDfnkqdLKMy0coMpEeErFTlaNCLodNxwXMRPy0
JNIXGSp48lZGX3Zmop8jYt3j0lRQ27BZO/MsE52o8t/rQ3hakNF3I5WJzslq
fjEiXEMeSil8wEQvXDZzRxFmSFrg0ndMtFr401GayDOXK52o6mciJmWriYQs
FTYoC+W/XGGi0zueHjxLPL97y3mrJvISkplQWdyiQIU8rZ6VNp0l1Jyi93IX
sX5vXeOH36yW0Fb7bIU7RH3q+kVHB/yXEE/Q3F1Pov6ZPfx84zFLSFKaoz6M
6E+tcfDzmfwlpJoVutpH9O+C+eeAlWdLaJx/sfMG0V+LAwbinN1LSLkOv7tP
9H+TbUHT+qkllN2zYs9F7M83R87zonzLaK2wb6XciAoFzoEqMsrLSOLgDcPi
vVTQ8ta9SDm2jEIl3bPP2VJhwf/6dv2wZUR53HJ/vxMV4OTakFH6Mirg6nD0
caGCVViTiX3TMsppoYb7B1IhMPEY2zndFTT+JW+YGk8F7ZTX5XTrFWQQaVPn
nEIFZoaye3zgCtqTp6Yemk2F+LwpuFawgg7qCr+3KaZCYXlsZC3/Kir+tFUo
/gNxPj8/XGD9tYo6L0QysqUiQX0T/ZzZfhYsoSJbRGqJhLsvFvsGDrHgtG/2
wbqdkSDlH2IZ5cWCe+ZC9575EQkCL/1layNZsLqsxRHByUiYOWHfQiljwUJq
deR2YRrUNqlKSwqz4odhMw/KPWiwP6rz7b8eVtzvndmxfYUG9eoHKam/WfGr
XNVXVZx0MPjSlKOxwIolfy7MawrQQUMTTvtvZMMX9TclsMvTYdOPYvGfxmz4
st4TTQVzOnzbST/ZXMSGF950Gj1OpoPd4OIX36dsePpT7dZD2XR4nxxizPGa
De9+xhk1fJMOdb/8yfg/NszanVDUXE6HWxn2r5/ys+MH0m1TF9vpEDCpKlIQ
zI6zH78SuM3FgPC8fb2WDHbMOHfle/g6Blyy9L+/cIUdb1xRfI43MKC4qGiP
dTE7fkx5OJshwoBqx0bu5Up2zNEhGCInzoBG0kj7vXp2HCO+wyJXkgEjbsq+
az/Z8RXGbSM7BQYsrN9LKfnDjg+nel1MVmYA9wufJccldtyl3u5XqcYAcmBc
AxsPCbsnNpfFqzNAWaww+ZEICctIcWne3MqA7e8aDh9RIOGKskNfCzQYYBY6
JM+pTcJxo54NVzQZ4CjP8bcckfC6Ux3cXloM8GlTqD52gITLhg/UKFAYcJZu
Es3jTMKDi+HjrYTjtnpZPvUjYVFLtmpvbQZk/XdBxP0sCVfHJFJ+Eb6bcLuX
L4aEt1vUnbTRYcCTHW/uV6eS8JqRUew9wvVD/SFe+SQcIwyXRgh3prMhgYck
rOP3PUNoGwMGDeV4ap+RcESfYc0WwjMThh2+jST8XvkqvwZhUp77DcFuEs7s
u3BvM2EhyyhfGCBh06eluTNEnjzzJiVwioQt9r1mqyGsXfRySWSNhIVNPCf8
CBs59ja85uPAQpb6YSTCtiSWlJPiHLiKa6IikVi/R4X0EXEVDnxcUvXpKlFv
sBtSeKvLgW/rpGQcIxy93vVvkDEHbpls8Ski+pVWS6uWtOHAdksXDH8S/SwI
yItucuHAJYuu+myEy8h1lqHHOTBO4/LdSPT/5dsfIrLhHDgmUO4HH7E/vXKS
JWGZHLj1vPVyI7Gfk58MQhVuc+CnSxWfElQZwEI/ij6VcWBOJ2XTHSoMkP4v
p0P5PbEevUEvJ0UGaCQ8v9HxlQN/WEfd9V6eAXt2/OdLH+bAkrb13FvlGOCS
Lr7czcaJJzpJPU+lGHDSUP9ttAAnPuhiubFHggG0icMpGlKcOG22P/UfcR5v
7L+mEKfHiWnDOW2/iPP6nZ18QPc0JxbnTy+e5GfAePkO0b5ITlyrV3w3ljjv
y66H+i4ncuLn9/bncvMwQKI2K3SwkBNf6uto/cLOAOcQ4bz0H5x4G2vK0X1T
dHiwJzdjbYwTWyyONZ35TYdlbvnEwAVOfDaL9x2V+J/MvaEVZizIhWuj44S2
fKXD97f7bf+Zc+GM0IVzK3V0UE9tN3d15MLLI2s9MtV0oDofRi2eXLglrlhS
gXhfJSd91G/TuPB+UntD8y06uIhFc9o94cKnD68Z3Iihw6MB7pW6V1y4Kjj/
+xsqHVYfJv9Ta+XC1bsgpyWEDvlGN3rZxrhwav5xCboXHXoDq59VSHPj41W+
Fp6GdPCo+3tyUyI3jtUdj9CZoUFFfKg3LZsbLwnkkAXGaMBmt+w8dpcbP74b
8a7tJw1uD/Pse/2SG3M3VFM5WmgwKKAoHzzHjTU9grdsv0kDH0/nz23uPNj1
gOv7JVMa+HM3otSdvFg6n7VsY1QkfFwS2Sdiyosr1K+RlkMiYduEt22ODS/+
433vVbdfJKx2sXvfDeDFpp63XF2sIyHjNrpUk8uL0/DxjFrie/1yT1VnH8s6
/G2PpPpINRXIoYX+2k3rcIGgR0DWYAQ09sWkdxzmx3tED7/l1g6HE1qGI46u
AnhHqJPjFp+zkL+pwfXXzEb80OZaVN6mM/CTqu4VES2IpWUezzlTTsOi3rZj
3ynCWC2os1tMJBDCTlADlHYK4+TRjuV37IGwcLP+3Ok9wliJ239j9FQAzHE5
pJH2C+NwJMcq/iEAprtC36l7CWPzluDuLzEBMBZURYnMEsb2yzd0U+f84Vux
PqfUkjDW/F38aKDfD56LGZa61otglm2sn972+EDcR+dxrRYRfDxyl6fERx+w
vnBWla1dBIdtr71Gf+EDg+Mlt+/8FMEfN/4bPZnrA+tfimSPMkUwXWloZPKI
D3j4jDPOUESxaIr1X8Y3b+B5fNX2Yp4ofnlnOrphwAs6fSuSne6K4vlHdIv3
nV6QJ/HhveoDUbx72ZPR2+AF2nFse9/XiGLn8AwtSpEXHD18YtfGLlE88MI4
5MwJLyhbM1LIWUfGpmo2IuFMTzhk+Xf2URgZT37p0oqR8gSjZIN9bnQyFnsS
9/zMRk9Qb7+UuzGOjH0DF0mnSZ7A5qRsHJJOxr31fR+Sxjzggadbit4jMk5l
/F7nXeUBbBHtavUDZPyAZPUt2I4YL650/Wolhs2SClu4M90ha5z0+JKDGCa1
mitdSXCHKE07ToOjYjgj/yq/FM0dHJ9OPMjzF8N3zBYivH3dgfWVCtMzRgzX
8vwruaRPjH+5nvG3RgznHNBjqg+4ASsXvYldURzHirs5v93tBmddKIWGW8Rx
40Yb6ZhtbjD+dCCaThHHnFd4b1lucYNuL3ODpd3/H3/Ts0J2gwevN5ZOO4rj
bU1U+dejruBIu5PRFy+O33msRNsec4X7s02uMC6Oj/+xaz5l7wL2g0Jz4U82
4z92Vy3WRx8FhtB+0TpvSayXXFKmF+oELazbHm44LolNys1MZ3ycQGRCwtg9
WBLfPJ3O/czJCR42/T1JoktiI60FVl8DJ/hGS3trkS2JhdJ+rzcjOYHu6NfQ
z82S+F63G49g1iEYe+HXOakphd+IvUC1rxzBwTcuVZ4phe31mCWjOxxgvMvw
0DKLNI415f9lssUBok1WJLq4pLGjX4F3iZQDlMmGFMUJS2PUKyN8ncMBeL+7
w6iWNA6WMrdf6bCHl9a7/5T6SuO8lfR9ncH2xP/mjLlBlzQeS2V7k1htB9Gc
FIaakwxO9DONd/GwhZ4Ylb9xzjI4P8LmfriTLeixyxwdcJHBRn6VNflWtjC5
tn5nrrcM1j1HjibtsgWXxfEJ/jMyeMM6ycEdQragP17kOnVFBh8hKZqgRhuY
apNB1W9k8MV1ZPWc7TbgdkNg1VRTFvf8aDzyQ80aWJWelflpy+Lj7vH6DHlr
uPXI0zNRVxbnHqraoSphDQNQ2fhplywWMi0JusJvDT79R9OdzWUxOeHVCYO+
g3BCuVglyF0WX3/kYlB16iCElxva5abLYr7Hsbt0M60gvSG4aHpeFk+f48rO
W7MEbVHFA7Ftcviw5MTmquB9oMQ8LFWcK4+FOyOeVt41g9cZ1dUN+fLYQ+uj
34McM3DRFLXrvyWPS1l6NhSnmkGWV+fFzcXyOEBWUK0q0gw4W62mrjyVx0Zu
PxWUHM1g6LZxffBHefzomevgfm4zuHNga4ABiwKO3bzGnxtkCrIFLJWtngo4
z7FCPuKQCXhQzUc0fRUwh26X+2ErE7hzKEU8JUABOxool+8xNQGV9TJ06yAF
vD+C47SUjgloRCDzNpoC9i73HKZsMIFdDrRv7dcUsOXTk9F3Go3BgWd5tatV
gahn+WoWNoaEoPm933cp4nmN4Yp8YyMQODRVx4YUMc0oLCrXwAiyDH7rqhop
4pTujIA8XSO4w/VT/qy5Ii6aek4tVzaClzferm1wUMRe/O3aQnxGsNCUWWV8
UhErF+WdbewyBF+5bcolNxVxWwf0fjpuCKYdpznDOZQwyeIrLb8Qw0kXfVj5
qYSdnp2r2dy0G/Iehu6JqVTGmfv6lXzf64Ncks5YDk0Ff6tjXFjw2AmC2YYp
1w6p4j3Vkq+T5baDk067h4qcGlZYVi9gOGyDO2mdSzUjapjto6faaKs2HNus
nEx5uQU/PJUQI+ZFgQDdZSv9BHXsSXvxmFtQCwbDZHlUPbfiw7nqSXmhW+Hx
gaaJIg0NHPBr9LmGwRZI+NWfu2VOA3u6t39RtlSFliJLk4yPmniY6fEm6LQy
UGgSfHsttXBDS9NnkRFFeFyr/6+yRguTDDbfDzqlADt/pO5WUaTgsu/XeOeU
5MHPTE3KI4GCF+67fzu7SQ6s6seW1s9RMH78dLVqTQZ6Lo2finHWxqqhTJaG
DTIQrKO8d6lOGzNmYkL4nKWgdjJh85CaDk5kd/YuDpWAsrmtcVeTdXBpVZb4
3iJxcN7I/FO7rIP7IwbWX88hg0+jErOJMM8hl62HCQfT7Tg/E945g/eTCcf/
eSA1RXjh0O7YrOtkeNLkelBxRQcbL22cTrtGBr7ohrIrhLd6KZQmXiVD3XTK
GZdVHXzL6XklNZ0MTcUv6IGEN0fLvN5FuNNtLDGMsN7F8ffMNDKMfTS+k0Y4
m6umN4ywaMlc51vCRqLyrKGpZDjteXS75poOjlPUVTyRTIYI8QQjA8JWxSRl
dcJxbU+t9hG+mKmv8juJDLlog68n4ehLX1X8CTdtfn31KuFZiQE57yvE89v/
3r5DuFR8SFqBcG/C5rJywvp7D0gMXCbD3HxIYwthEQFrQXfCrKUFnV8IM2+M
8csQ5vP52DtEeHT3b66ficR6JZfGp/+fN2LDmkdYrlN5cY2w2FUp5lHC/wNc
tXpE
      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.1, -0.0309532}, {0.2, -0.0279277}, {0.5, -0.0187654}, {
     0.75, -0.0149042}, {1., -0.00961638}, {1.5, -0.00698553}, {
     2., -0.00722254}, {2.5, -0.00789598}, {3., -0.00765113}, {
     3.5, -0.00675284}, {4., -0.00566786}, {4.5, -0.00463532}, {
     5., -0.00375828}, {7., -0.00170315}, {9., -0.000881284}, {
     11., -0.000509589}, {14., -0.000259545}, {17., -0.000149382}, {
     20., -0.0000936294}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.016836681649852758`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.498604503018375*^9}],

Cell[BoxData[
 RowBox[{"-", "0.057711227123713855`"}]], "Output",
 CellChangeTimes->{3.498604503046689*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1702: cL=.587, -cR=.587 cLi=.587, -cRi=.587", "Subsection",
 CellChangeTimes->{{3.497313889939773*^9, 3.497313893298924*^9}, {
  3.497314493802484*^9, 3.497314497168442*^9}, {3.498603616714102*^9, 
  3.4986036383587093`*^9}, {3.498604023449239*^9, 3.498604049600122*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tempA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000461443"}], ",", 
     RowBox[{"-", "0.0703745"}], ",", 
     RowBox[{"-", "0.0782309"}], ",", 
     RowBox[{"-", "0.0387801"}], ",", 
     RowBox[{"-", "0.023582"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0154021"}], ",", 
     RowBox[{"-", "0.00886119"}], ",", 
     RowBox[{"-", "0.00819218"}], ",", 
     RowBox[{"-", "0.008371"}], ",", 
     RowBox[{"-", "0.00779047"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00667064"}], ",", 
     RowBox[{"-", "0.00545858"}], ",", 
     RowBox[{"-", "0.00438571"}], ",", 
     RowBox[{"-", "0.00351284"}], ",", 
     RowBox[{"-", "0.00155389"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000796129"}], ",", 
     RowBox[{"-", "0.000457815"}], ",", 
     RowBox[{"-", "0.000232031"}], ",", 
     RowBox[{"-", "0.000133145"}], ",", 
     RowBox[{"-", "0.0000832823"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1702", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1702", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1702"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1702", "=", 
  RowBox[{"Interpolation", "[", "Run1702", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1702", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1702", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"M\[Mu]\[Mu]\[Mu]\[Mu]", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1702", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}, {3.49860406888894*^9, 
  3.498604141520383*^9}, {3.4986042445205603`*^9, 3.49860425027288*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.000461443`"}], ",", 
   RowBox[{"-", "0.0703745`"}], ",", 
   RowBox[{"-", "0.0782309`"}], ",", 
   RowBox[{"-", "0.0387801`"}], ",", 
   RowBox[{"-", "0.023582`"}], ",", 
   RowBox[{"-", "0.0154021`"}], ",", 
   RowBox[{"-", "0.00886119`"}], ",", 
   RowBox[{"-", "0.00819218`"}], ",", 
   RowBox[{"-", "0.008371`"}], ",", 
   RowBox[{"-", "0.00779047`"}], ",", 
   RowBox[{"-", "0.00667064`"}], ",", 
   RowBox[{"-", "0.00545858`"}], ",", 
   RowBox[{"-", "0.00438571`"}], ",", 
   RowBox[{"-", "0.00351284`"}], ",", 
   RowBox[{"-", "0.00155389`"}], ",", 
   RowBox[{"-", "0.000796129`"}], ",", 
   RowBox[{"-", "0.000457815`"}], ",", 
   RowBox[{"-", "0.000232031`"}], ",", 
   RowBox[{"-", "0.000133145`"}], ",", 
   RowBox[{"-", "0.0000832823`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.01`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
   "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.498604142526063*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, -0.0004619396824665084}, {
      0.016131291231986936`, -0.007721851669388408}, {
      0.022262174504790202`, -0.014579075296426207`}, {
      0.024518004544853648`, -0.016957261930452272`}}], 
     LineBox[CompressedData["
1:eJwV1XdYTu8bAPC3t51K4W280d7RkFDi3A0pFSXSVloqUinKqPO2tGiSKKLQ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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, -0.000461443}, {0.1, -0.0703745}, {0.2, -0.0782309}, {
     0.5, -0.0387801}, {0.75, -0.023582}, {1., -0.0154021}, {
     1.5, -0.00886119}, {2., -0.00819218}, {2.5, -0.008371}, {
     3., -0.00779047}, {3.5, -0.00667064}, {4., -0.00545858}, {
     4.5, -0.00438571}, {5., -0.00351284}, {7., -0.00155389}, {
     9., -0.000796129}, {11., -0.000457815}, {14., -0.000232031}, {
     17., -0.000133145}, {20., -0.0000832823}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.016957261930452272`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.498604142527865*^9}],

Cell[BoxData[
 RowBox[{"-", "0.07559098098999252`"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.498604142561017*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1703: cL=.537, -cR=.537 cLi=.537, -cRi=.537", "Subsection",
 CellChangeTimes->{{3.497313889939773*^9, 3.497313893298924*^9}, {
   3.497314493802484*^9, 3.497314497168442*^9}, {3.498603616714102*^9, 
   3.4986036383587093`*^9}, {3.498604023449239*^9, 3.498604049600122*^9}, 
   3.498604171082603*^9, {3.498604231544888*^9, 3.498604257201014*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tempA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000395676"}], ",", 
     RowBox[{"-", "0.0760454"}], ",", 
     RowBox[{"-", "0.0852246"}], ",", 
     RowBox[{"-", "0.0420024"}], ",", 
     RowBox[{"-", "0.0254484"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.016364"}], ",", 
     RowBox[{"-", "0.00936076"}], ",", 
     RowBox[{"-", "0.00857224"}], ",", 
     RowBox[{"-", "0.00855804"}], ",", 
     RowBox[{"-", "0.00777847"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00653525"}], ",", 
     RowBox[{"-", "0.00527335"}], ",", 
     RowBox[{"-", "0.00419429"}], ",", 
     RowBox[{"-", "0.00333508"}], ",", 
     RowBox[{"-", "0.0014537"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000740257"}], ",", 
     RowBox[{"-", "0.000424233"}], ",", 
     RowBox[{"-", "0.000214355"}], ",", 
     RowBox[{"-", "0.000122772"}], ",", 
     RowBox[{"-", "0.0000766966"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1703", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1703", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1703"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1703", "=", 
  RowBox[{"Interpolation", "[", "Run1703", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1703", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1703", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"M\[Tau]\[Tau]\[Tau]\[Tau]", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1703", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}, {3.49860406888894*^9, 
  3.498604141520383*^9}, {3.498604269095121*^9, 3.498604288257567*^9}, {
  3.498604319498402*^9, 3.498604366827651*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.000395676`"}], ",", 
   RowBox[{"-", "0.0760454`"}], ",", 
   RowBox[{"-", "0.0852246`"}], ",", 
   RowBox[{"-", "0.0420024`"}], ",", 
   RowBox[{"-", "0.0254484`"}], ",", 
   RowBox[{"-", "0.016364`"}], ",", 
   RowBox[{"-", "0.00936076`"}], ",", 
   RowBox[{"-", "0.00857224`"}], ",", 
   RowBox[{"-", "0.00855804`"}], ",", 
   RowBox[{"-", "0.00777847`"}], ",", 
   RowBox[{"-", "0.00653525`"}], ",", 
   RowBox[{"-", "0.00527335`"}], ",", 
   RowBox[{"-", "0.00419429`"}], ",", 
   RowBox[{"-", "0.00333508`"}], ",", 
   RowBox[{"-", "0.0014537`"}], ",", 
   RowBox[{"-", "0.000740257`"}], ",", 
   RowBox[{"-", "0.000424233`"}], ",", 
   RowBox[{"-", "0.000214355`"}], ",", 
   RowBox[{"-", "0.000122772`"}], ",", 
   RowBox[{"-", "0.0000766966`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.01`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
   "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368845289*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, -0.0003962113140264928}, {
      0.016131291231986936`, -0.008222461172328527}, {
      0.021973391029420555`, -0.015269604649751429`}}], 
     LineBox[CompressedData["
1:eJwV1nc4lt8bAPB3GVlJ9t6rMpIS8tzWNxFZlZCRPRKS0cD7GhlFIVHSoFIp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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, -0.000395676}, {0.1, -0.0760454}, {0.2, -0.0852246}, {
     0.5, -0.0420024}, {0.75, -0.0254484}, {1., -0.016364}, {
     1.5, -0.00936076}, {2., -0.00857224}, {2.5, -0.00855804}, {
     3., -0.00777847}, {3.5, -0.00653525}, {4., -0.00527335}, {
     4.5, -0.00419429}, {5., -0.00333508}, {7., -0.0014537}, {
     9., -0.000740257}, {11., -0.000424233}, {14., -0.000214355}, {
     17., -0.000122772}, {20., -0.0000766966}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.015269604649751429`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.4986043688470907`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.07863150263761148`"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.49860436887906*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1704: cL=.667, -cR=.667 cLi=.537, -cRi=.537", "Subsection",
 CellChangeTimes->{{3.497313889939773*^9, 3.497313893298924*^9}, {
   3.497314493802484*^9, 3.497314497168442*^9}, {3.498603616714102*^9, 
   3.4986036383587093`*^9}, {3.498604023449239*^9, 3.498604049600122*^9}, 
   3.498604171082603*^9, {3.498604231544888*^9, 3.498604257201014*^9}, {
   3.498604641146653*^9, 3.498604654273984*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tempA", "=", 
   RowBox[{"{", 
    RowBox[{"0.012169", ",", 
     RowBox[{"-", "0.0381672"}], ",", 
     RowBox[{"-", "0.0471113"}], ",", 
     RowBox[{"-", "0.0231362"}], ",", 
     RowBox[{"-", "0.0147869"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0119012"}], ",", 
     RowBox[{"-", "0.00751974"}], ",", 
     RowBox[{"-", "0.00745848"}], ",", 
     RowBox[{"-", "0.00761013"}], ",", 
     RowBox[{"-", "0.00717172"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00611395"}], ",", 
     RowBox[{"-", "0.00502689"}], ",", 
     RowBox[{"-", "0.0040428"}], ",", 
     RowBox[{"-", "0.00323822"}], ",", 
     RowBox[{"-", "0.00143152"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000732655"}], ",", 
     RowBox[{"-", "0.000420937"}], ",", 
     RowBox[{"-", "0.000213132"}], ",", 
     RowBox[{"-", "0.000122218"}], ",", 
     RowBox[{"-", "0.0000764104"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1704", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1704", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals", ",", "r1704"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1704", "=", 
  RowBox[{"Interpolation", "[", "Run1704", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1704", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1704", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mee\[Tau]\[Tau]", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1704", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}, {3.49860406888894*^9, 
  3.498604141520383*^9}, {3.498604269095121*^9, 3.498604288257567*^9}, {
  3.498604319498402*^9, 3.498604366827651*^9}, {3.498604662912567*^9, 
  3.498604789081802*^9}, {3.498604838810091*^9, 3.4986048389779873`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.012169`", ",", 
   RowBox[{"-", "0.0381672`"}], ",", 
   RowBox[{"-", "0.0471113`"}], ",", 
   RowBox[{"-", "0.0231362`"}], ",", 
   RowBox[{"-", "0.0147869`"}], ",", 
   RowBox[{"-", "0.0119012`"}], ",", 
   RowBox[{"-", "0.00751974`"}], ",", 
   RowBox[{"-", "0.00745848`"}], ",", 
   RowBox[{"-", "0.00761013`"}], ",", 
   RowBox[{"-", "0.00717172`"}], ",", 
   RowBox[{"-", "0.00611395`"}], ",", 
   RowBox[{"-", "0.00502689`"}], ",", 
   RowBox[{"-", "0.0040428`"}], ",", 
   RowBox[{"-", "0.00323822`"}], ",", 
   RowBox[{"-", "0.00143152`"}], ",", 
   RowBox[{"-", "0.000732655`"}], ",", 
   RowBox[{"-", "0.000420937`"}], ",", 
   RowBox[{"-", "0.000213132`"}], ",", 
   RowBox[{"-", "0.000122218`"}], ",", 
   RowBox[{"-", "0.0000764104`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498604839605288*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.01`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
   "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498604839614422*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{{0.010000407959183673`, 0.012168651858410116`}, {
      0.016131291231986936`, 0.0070727342141245556`}, {0.022262174504790202`, 
      0.0022449751885310065`}, {
      0.028393057777593468`, -0.0023204084728633556`}, {
      0.03452394105039673, -0.006629200024551349}, {
      0.040654824323199994`, -0.010687182721025763`}, {
      0.046785707596003256`, -0.014500139816779414`}, {
      0.048837007646250714`, -0.01565679434866813}}], 
     LineBox[{{0.3879117542287656, -0.01565679434866813}, {
      0.3901151708729861, -0.015412979058761943`}, {
      0.39624605414578934`, -0.014819196590045483`}, {
      0.4023769374185926, -0.014315817281191115`}, {
      0.40902351742983833`, -0.013878942320241821`}, {
      0.415670097441084, -0.013562484498471125`}, {
      0.4223166774523297, -0.013373812634598598`}, {
      0.42896325746357544`, -0.013320295547344018`}, {
      0.4356098374748212, -0.013409302055427029`}, {
      0.44225641748606687`, -0.013648200977567339`}, {
      0.44890299749731255`, -0.014044361132484542`}, {
      0.4555495775085583, -0.014605151338898397`}, {
      0.46219615751980403`, -0.015337940415528564`}, {
      0.4645195390464401, -0.01565679434866813}}], LineBox[CompressedData["
1:eJwV13c8Vt8fAHAeW8jM3rskIw3rHCuyS1H2Fr5JQsLzPBmZGZlpiFDKTBGp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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.01, 0.012169}, {0.1, -0.0381672}, {0.2, -0.0471113}, {
     0.5, -0.0231362}, {0.75, -0.0147869}, {1., -0.0119012}, {
     1.5, -0.00751974}, {2., -0.00745848}, {2.5, -0.00761013}, {
     3., -0.00717172}, {3.5, -0.00611395}, {4., -0.00502689}, {
     4.5, -0.0040428}, {5., -0.00323822}, {7., -0.00143152}, {
     9., -0.000732655}, {11., -0.000420937}, {14., -0.000213132}, {
     17., -0.000122218}, {20., -0.0000764104}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.01565679434866813, 0.012168651858410116`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498604839620479*^9}],

Cell[BoxData[
 RowBox[{"-", "0.05676955868540681`"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498604839650531*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1705: cL=.537, -cR=.667 cLi=.537, -cRi=.667", "Subsection",
 CellChangeTimes->{{3.497313889939773*^9, 3.497313893298924*^9}, {
   3.497314493802484*^9, 3.497314497168442*^9}, {3.498603616714102*^9, 
   3.4986036383587093`*^9}, {3.498604023449239*^9, 3.498604049600122*^9}, 
   3.498604171082603*^9, {3.498604231544888*^9, 3.498604257201014*^9}, {
   3.498604641146653*^9, 3.498604654273984*^9}, 3.498604827931499*^9, {
   3.4986050362058697`*^9, 3.4986050587156887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tempA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0594372"}], ",", 
     RowBox[{"-", "0.0529778"}], ",", 
     RowBox[{"-", "0.0334093"}], ",", 
     RowBox[{"-", "0.0210193"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014785"}], ",", 
     RowBox[{"-", "0.00868922"}], ",", 
     RowBox[{"-", "0.00806118"}], ",", 
     RowBox[{"-", "0.00828679"}], ",", 
     RowBox[{"-", "0.00774191"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00667908"}], ",", 
     RowBox[{"-", "0.00549292"}], ",", 
     RowBox[{"-", "0.0044311"}], ",", 
     RowBox[{"-", "0.00355919"}], ",", 
     RowBox[{"-", "0.00158246"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.000812376"}], ",", 
     RowBox[{"-", "0.000467665"}], ",", 
     RowBox[{"-", "0.00023725"}], ",", 
     RowBox[{"-", "0.000136219"}], ",", 
     RowBox[{"-", "0.0000852382"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1705", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempA", ",", "tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1705", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvalsshort", ",", "r1705"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1705", "=", 
  RowBox[{"Interpolation", "[", "Run1705", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1705", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1705", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"M\[Tau]e\[Tau]e", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1705", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}, {3.49860406888894*^9, 
  3.498604141520383*^9}, {3.498604269095121*^9, 3.498604288257567*^9}, {
  3.498604319498402*^9, 3.498604366827651*^9}, {3.498604662912567*^9, 
  3.498604789081802*^9}, {3.4986051125742188`*^9, 3.4986052004839087`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0594372`"}], ",", 
   RowBox[{"-", "0.0529778`"}], ",", 
   RowBox[{"-", "0.0334093`"}], ",", 
   RowBox[{"-", "0.0210193`"}], ",", 
   RowBox[{"-", "0.014785`"}], ",", 
   RowBox[{"-", "0.00868922`"}], ",", 
   RowBox[{"-", "0.00806118`"}], ",", 
   RowBox[{"-", "0.00828679`"}], ",", 
   RowBox[{"-", "0.00774191`"}], ",", 
   RowBox[{"-", "0.00667908`"}], ",", 
   RowBox[{"-", "0.00549292`"}], ",", 
   RowBox[{"-", "0.0044311`"}], ",", 
   RowBox[{"-", "0.00355919`"}], ",", 
   RowBox[{"-", "0.00158246`"}], ",", 
   RowBox[{"-", "0.000812376`"}], ",", 
   RowBox[{"-", "0.000467665`"}], ",", 
   RowBox[{"-", "0.00023725`"}], ",", 
   RowBox[{"-", "0.000136219`"}], ",", 
   RowBox[{"-", "0.0000852382`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, 3.4986054700572977`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.1`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, 3.498605470066174*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterpolatingFunction", "::", "\<\"dmval\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\({0.010408367142857143`}\\) lies outside \
the range of data in the interpolating function. Extrapolation will be used. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.4986052027377863`*^9, 3.4986054700688353`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc8Vf8bAPBrS1KUnT2TjKRvos5jlBESJXtfm2RVCsdNIoRIkSQrIZHS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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.1, -0.0594372}, {0.2, -0.0529778}, {0.5, -0.0334093}, {
     0.75, -0.0210193}, {1., -0.014785}, {1.5, -0.00868922}, {
     2., -0.00806118}, {2.5, -0.00828679}, {3., -0.00774191}, {
     3.5, -0.00667908}, {4., -0.00549292}, {4.5, -0.0044311}, {
     5., -0.00355919}, {7., -0.00158246}, {9., -0.000812376}, {
     11., -0.000467665}, {14., -0.00023725}, {17., -0.000136219}, {
     20., -0.0000852382}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.016938416613145175`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, 3.498605470073831*^9}],

Cell[BoxData[
 RowBox[{"-", "0.07486824502130898`"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, 3.498605470102111*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run 1706: cL=.537, -cR=.667 cLi=.537, -cRi=.667", "Subsection",
 CellChangeTimes->{{3.497313889939773*^9, 3.497313893298924*^9}, {
   3.497314493802484*^9, 3.497314497168442*^9}, {3.498603616714102*^9, 
   3.4986036383587093`*^9}, {3.498604023449239*^9, 3.498604049600122*^9}, 
   3.498604171082603*^9, {3.498604231544888*^9, 3.498604257201014*^9}, {
   3.498604641146653*^9, 3.498604654273984*^9}, 3.498604827931499*^9, {
   3.4986050362058697`*^9, 3.4986050587156887`*^9}, 3.498605220931728*^9}],

Cell["\<\
This was very ill behaved in the IR. Had to truncate first five elements.\
\>", "Text",
 CellChangeTimes->{{3.49860529388736*^9, 3.498605302036661*^9}, {
  3.4986053322393713`*^9, 3.498605335532404*^9}, {3.4986053804931993`*^9, 
  3.498605382676818*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"yvals1706", "=", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "1.5`", ",", "2", ",", "2.5`", ",", "3", ",", "3.5`", ",", "4", 
    ",", "4.5`", ",", "5", ",", "7", ",", "9", ",", "11", ",", "14", ",", 
    "17", ",", "20"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0102031"}], ",", 
     RowBox[{"-", "0.00798603"}], ",", 
     RowBox[{"-", "0.00716863"}], ",", 
     RowBox[{"-", "0.00783932"}], ",", 
     RowBox[{"-", "0.00759151"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0066803"}], ",", 
     RowBox[{"-", "0.00555728"}], ",", 
     RowBox[{"-", "0.00451344"}], ",", 
     RowBox[{"-", "0.0036419"}], ",", 
     RowBox[{"-", "0.00163428"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00084214"}], ",", 
     RowBox[{"-", "0.000485798"}], ",", 
     RowBox[{"-", "0.000246895"}], ",", 
     RowBox[{"-", "0.000141912"}], ",", 
     RowBox[{"-", "0.000088866"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"r1706", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"tempB", ",", "tempC", ",", "tempD"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tempB", ",", "tempC", ",", "tempD"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Run1706", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yvals1706", ",", "r1706"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f1706", "=", 
  RowBox[{"Interpolation", "[", "Run1706", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f1706", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".01", ",", "20"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ListPlot", "[", "Run1706", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mxyxy", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"f1706", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.496332390101012*^9, 3.496332396750049*^9}, {
  3.4963324443273993`*^9, 3.496332473248671*^9}, {3.4963325345926723`*^9, 
  3.4963325692117653`*^9}, {3.496332618694811*^9, 3.496332634247308*^9}, {
  3.4963332562508497`*^9, 3.496333259393612*^9}, {3.496333519524557*^9, 
  3.496333519791274*^9}, {3.496501217249208*^9, 3.496501233599752*^9}, {
  3.497313913166542*^9, 3.4973140072243357`*^9}, {3.497314134123207*^9, 
  3.497314172236497*^9}, {3.4973142044643393`*^9, 3.497314213531653*^9}, {
  3.4973144818051443`*^9, 3.497314482002202*^9}, {3.497314514111042*^9, 
  3.497314533756076*^9}, {3.498603662958976*^9, 3.498603849927557*^9}, {
  3.498603952833147*^9, 3.4986039830479517`*^9}, {3.49860406888894*^9, 
  3.498604141520383*^9}, {3.498604269095121*^9, 3.498604288257567*^9}, {
  3.498604319498402*^9, 3.498604366827651*^9}, {3.498604662912567*^9, 
  3.498604789081802*^9}, {3.4986051125742188`*^9, 3.4986052004839087`*^9}, {
  3.498605303565229*^9, 3.498605466369742*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1.5`", ",", "2", ",", "2.5`", ",", "3", ",", "3.5`", ",", "4", 
   ",", "4.5`", ",", "5", ",", "7", ",", "9", ",", "11", ",", "14", ",", "17",
    ",", "20"}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, {3.49860544403209*^9, 3.498605467228787*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0102031`"}], ",", 
   RowBox[{"-", "0.00798603`"}], ",", 
   RowBox[{"-", "0.00716863`"}], ",", 
   RowBox[{"-", "0.00783932`"}], ",", 
   RowBox[{"-", "0.00759151`"}], ",", 
   RowBox[{"-", "0.0066803`"}], ",", 
   RowBox[{"-", "0.00555728`"}], ",", 
   RowBox[{"-", "0.00451344`"}], ",", 
   RowBox[{"-", "0.0036419`"}], ",", 
   RowBox[{"-", "0.00163428`"}], ",", 
   RowBox[{"-", "0.00084214`"}], ",", 
   RowBox[{"-", "0.000485798`"}], ",", 
   RowBox[{"-", "0.000246895`"}], ",", 
   RowBox[{"-", "0.000141912`"}], ",", 
   RowBox[{"-", "0.000088866`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, {3.49860544403209*^9, 3.49860546723088*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, {3.49860544403209*^9, 3.498605467232456*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"InterpolatingFunction", "::", "\<\"dmval\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\({0.010408367142857143`}\\) lies outside \
the range of data in the interpolating function. Extrapolation will be used. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.4986052027377863`*^9, {3.4986054441020107`*^9, 3.4986054672662354`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Xk0lV8XB/DrusYkmed5qswSSZ6NSBkyhETmIfqliEjdIZkpQiqVCkUS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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{1., -0.0102031}, {1.5, -0.00798603}, {2., -0.00716863}, {
     2.5, -0.00783932}, {3., -0.00759151}, {3.5, -0.0066803}, {
     4., -0.00555728}, {4.5, -0.00451344}, {5., -0.0036419}, {
     7., -0.00163428}, {9., -0.00084214}, {11., -0.000485798}, {
     14., -0.000246895}, {17., -0.000141912}, {20., -0.000088866}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.01, 20}, {-0.018376130833719077`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, {3.49860544403209*^9, 3.498605467299124*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.051442218699404824`"}]], "Output",
 CellChangeTimes->{{3.497314176006219*^9, 3.497314219071507*^9}, {
   3.4973145170475807`*^9, 3.497314553714883*^9}, {3.498603853992282*^9, 
   3.498603876766838*^9}, {3.498603954127486*^9, 3.498603983329694*^9}, 
   3.49860414252389*^9, 3.498604368843124*^9, 3.498604792373188*^9, 
   3.498605202733843*^9, {3.49860544403209*^9, 3.49860546733278*^9}}]
}, Open  ]],

Cell["\<\
Can do a sanity check to see if this result is reasonable (doesn't look like \
it). Compare the value of integrals when we only integrate from the known \
points, e.g. x=1. \
\>", "Text",
 CellChangeTimes->{{3.498605520425317*^9, 3.498605549437705*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"f1706", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"f1705", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"f1704", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1", ",", "20"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.498605489828867*^9, 3.4986054998314238`*^9}, {
  3.498605564420759*^9, 3.498605567704782*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.03750699369940481`"}]], "Output",
 CellChangeTimes->{3.4986055004392223`*^9, 3.4986055679610147`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.03900467452961314`"}]], "Output",
 CellChangeTimes->{3.4986055004392223`*^9, 3.498605567970525*^9}],

Cell[BoxData[
 RowBox[{"-", "0.03523776149449409`"}]], "Output",
 CellChangeTimes->{3.4986055004392223`*^9, 3.498605567972374*^9}]
}, Open  ]],

Cell["\<\
We find that the ratio between these perhaps shouldn't be so big. I suggest \
discarding the information of this run, but it's the only information about \
the custodial case. At the very least it's evidence that we're in the same \
ballpark and that we don't drift very far from the minimal model within \
better than an order of magnitude. \
\>", "Text",
 CellChangeTimes->{{3.4986055539243803`*^9, 3.49860556089392*^9}, {
  3.4986056069183683`*^9, 3.4986056405179*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{681, 661},
WindowMargins->{{150, Automatic}, {Automatic, 29}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (March 13, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 177, 2, 76, "Title"],
Cell[770, 27, 576, 12, 116, "Text"],
Cell[1349, 41, 144, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[1518, 47, 104, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[1647, 52, 912, 26, 88, "Input"],
Cell[2562, 80, 441, 8, 27, "Output"]
}, Open  ]],
Cell[3018, 91, 412, 9, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3467, 105, 101, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[3593, 110, 236, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[3854, 117, 3089, 82, 214, "Input"],
Cell[6946, 201, 1018, 24, 73, "Output"],
Cell[7967, 227, 447, 12, 27, "Output"],
Cell[8417, 241, 11039, 187, 222, "Output"],
Cell[19459, 430, 276, 4, 27, "Output"]
}, Open  ]],
Cell[19750, 437, 417, 9, 56, "Text"],
Cell[CellGroupData[{
Cell[20192, 450, 3065, 80, 208, "Input"],
Cell[23260, 532, 840, 22, 73, "Output"],
Cell[24103, 556, 276, 10, 27, "Output"],
Cell[24382, 568, 544, 11, 59, "Message"],
Cell[24929, 581, 8729, 150, 223, "Output"],
Cell[33661, 733, 107, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33817, 741, 281, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[34123, 748, 3149, 81, 208, "Input"],
Cell[37275, 831, 1071, 26, 73, "Output"],
Cell[38349, 859, 476, 13, 27, "Output"],
Cell[38828, 874, 8870, 152, 223, "Output"],
Cell[47701, 1028, 304, 5, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48054, 1039, 355, 4, 34, "Subsection"],
Cell[CellGroupData[{
Cell[48434, 1047, 3202, 82, 208, "Input"],
Cell[51639, 1131, 1094, 26, 73, "Output"],
Cell[52736, 1159, 497, 13, 27, "Output"],
Cell[53236, 1174, 8590, 147, 223, "Output"],
Cell[61829, 1323, 324, 5, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62202, 1334, 405, 5, 34, "Subsection"],
Cell[CellGroupData[{
Cell[62632, 1343, 3266, 82, 208, "Input"],
Cell[65901, 1427, 1121, 26, 73, "Output"],
Cell[67025, 1455, 545, 14, 27, "Output"],
Cell[67573, 1471, 10537, 180, 222, "Output"],
Cell[78113, 1653, 373, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78535, 1665, 481, 6, 34, "Subsection"],
Cell[CellGroupData[{
Cell[79041, 1675, 3254, 82, 208, "Input"],
Cell[82298, 1759, 1125, 26, 73, "Output"],
Cell[83426, 1787, 565, 14, 27, "Output"],
Cell[83994, 1803, 570, 11, 59, "Message"],
Cell[84567, 1816, 8408, 144, 223, "Output"],
Cell[92978, 1962, 395, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93422, 1974, 503, 6, 34, "Subsection"],
Cell[93928, 1982, 264, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[94217, 1991, 3271, 81, 208, "Input"],
Cell[97491, 2074, 584, 10, 27, "Output"],
Cell[98078, 2086, 992, 22, 58, "Output"],
Cell[99073, 2110, 584, 13, 27, "Output"],
Cell[99660, 2125, 599, 12, 59, "Message"],
Cell[100262, 2139, 8491, 144, 223, "Output"],
Cell[108756, 2285, 418, 6, 27, "Output"]
}, Open  ]],
Cell[109189, 2294, 263, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[109477, 2303, 664, 19, 58, "Input"],
Cell[110144, 2324, 132, 2, 27, "Output"],
Cell[110279, 2328, 130, 2, 27, "Output"],
Cell[110412, 2332, 130, 2, 27, "Output"]
}, Open  ]],
Cell[110557, 2337, 482, 8, 56, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
